_positive = set(
    [
        "アバ",
        "能力",
        "NO TRANSLATION",
        "絶対の",
        "赦免",
        "吸収された",
        "豊富",
        "アカデミック",
        "アカデミー",
        "許容可能な",
        "受け入れ",
        "アクセス可能な",
        "称賛",
        "宿泊施設",
        "伴奏",
        "達成する",
        "達成された",
        "達成",
        "アコード",
        "説明責任",
        "説明責任",
        "認定された",
        "NO TRANSLATION",
        "正確",
        "エース",
        "達成する",
        "成果",
        "了承",
        "獲得する",
        "取得する",
        "アクロバット",
        "アクション",
        "実際の",
        "視力",
        "洞察力",
        "適応する",
        "適応性のある",
        "アドレス",
        "熟達した",
        "NO TRANSLATION",
        "補助",
        "素晴らしい",
        "提督",
        "感嘆",
        "賞賛する",
        "賛美者",
        "容認できる",
        "愛らしい",
        "礼拝",
        "崇拝します",
        "前進",
        "高度な",
        "アドバンス",
        "利点",
        "有利",
        "出現",
        "冒険",
        "冒険的な",
        "お勧め",
        "アドバイス",
        "顧問",
        "アドボカシー",
        "美的",
        "美学",
        "親切な",
        "愛情",
        "提携",
        "肯定する",
        "肯定",
        "肯定的な",
        "肯定的に",
        "豊かな",
        "豊かな",
        "余裕",
        "NO TRANSLATION",
        "アジャイル",
        "敏捷性",
        "同意する",
        "楽しい",
        "同意した",
        "同意する",
        "契約",
        "農業",
        "前方に",
        "援助",
        "助ける",
        "アラバスター",
        "警戒",
        "NO TRANSLATION",
        "生きている",
        "和らげる",
        "忠誠",
        "アレグロ",
        "緩和する",
        "軽減",
        "同盟",
        "許容できる",
        "魅力",
        "魅力的な",
        "アリー",
        "全能",
        "アロハ",
        "驚くほど",
        "大使",
        "野心",
        "改善する",
        "アーメン",
        "従順な",
        "修正する",
        "補償",
        "アメニティ",
        "愉快な",
        "親切な",
        "恩赦",
        "NO TRANSLATION",
        "楽しむ",
        "面白い",
        "アミューズメント",
        "面白い",
        "アナリスト",
        "アンカー",
        "足場",
        "天使",
        "天使の",
        "アニメーション化する",
        "アニメーション",
        "抗生物質",
        "解毒剤",
        "抗真菌剤",
        "アンティーク",
        "消毒剤",
        "腹を立てる",
        "謝罪する",
        "お詫びする",
        "謝罪",
        "使徒",
        "拍手",
        "感謝",
        "承認",
        "承認",
        "承認する",
        "承認する",
        "適切",
        "適性",
        "考古学",
        "熱烈な",
        "熱烈な",
        "貴族",
        "貴族の",
        "鎧",
        "香り",
        "興奮する",
        "アレイ",
        "アート",
        "明瞭な",
        "関節運動",
        "職人",
        "NO TRANSLATION",
        "芸術的",
        "優位",
        "上昇",
        "吸引",
        "熱望する",
        "志望する",
        "アセンブリ",
        "同意する",
        "断言する",
        "資産",
        "支援する",
        "支援",
        "関連付ける",
        "安楽死",
        "保証",
        "保証された",
        "NO TRANSLATION",
        "驚き",
        "占星術師",
        "宇宙飛行士",
        "天文学者",
        "鋭い",
        "アスリート",
        "運動",
        "原子",
        "償う",
        "償い",
        "アタッチメント",
        "達成可能な",
        "達成",
        "アテンダント",
        "注意",
        "注意深い",
        "証明する",
        "弁護士",
        "アトラクション",
        "魅力",
        "増強",
        "8月",
        "叔母",
        "オーラ",
        "幸運な",
        "本物の",
        "信憑性",
        "著者",
        "権威ある",
        "権限",
        "承認",
        "承認された",
        "アバター",
        "賞",
        "ay",
        "エイ",
        "赤ちゃん",
        "バカロレア",
        "背骨",
        "バランス",
        "バランス",
        "バラード",
        "バレエ",
        "投票",
        "バルサム",
        "バンケット",
        "洗礼",
        "洗礼",
        "バード",
        "バーゲン",
        "バスケットボール",
        "要塞",
        "浴",
        "ビーム",
        "ビーム",
        "美化",
        "綺麗な",
        "美しく",
        "美しさ",
        "岩盤",
        "ビール",
        "適合する",
        "仲良くする",
        "信じる",
        "恩人",
        "有益",
        "利益",
        "慈悲",
        "良性",
        "バース",
        "婚約者",
        "改善",
        "飲料",
        "聖書的",
        "バイリンガル",
        "誕生",
        "お誕生日",
        "無防備な",
        "祝福",
        "祝福された",
        "祝福",
        "祝福",
        "至福",
        "幸福な",
        "無血",
        "咲く",
        "花",
        "ボディーガード",
        "大胆な",
        "大胆さ",
        "強化する",
        "バンザン",
        "NO TRANSLATION",
        "ボーナス",
        "予約する",
        "書店",
        "恩恵",
        "豊かな",
        "賞金",
        "花束",
        "頭脳",
        "勇気",
        "朝ごはん",
        "ブライダル",
        "花嫁",
        "花婿",
        "花嫁介添人",
        "明るく",
        "輝度",
        "ブリリアント",
        "ブロケード",
        "兄",
        "兄弟愛",
        "兄弟",
        "バディ",
        "ビルドする",
        "建物",
        "ブルドッグ",
        "防弾",
        "ブイ",
        "バス",
        "執事",
        "バター",
        "バクソム",
        "バズ",
        "タクシー",
        "キャビネット",
        "カフェ",
        "電卓",
        "カーフ",
        "落ち着いた",
        "カナリア",
        "率直",
        "候補者",
        "甘酸っぱい",
        "資本主義者",
        "キャプテン",
        "魅了する",
        "魅力的な",
        "キャリア",
        "慎重に",
        "慎重に",
        "愛撫",
        "介護者",
        "キャロル",
        "カスケード",
        "現金",
        "カテゴリ",
        "食べる",
        "カタルシス",
        "大聖堂",
        "慎重な",
        "慎重に",
        "祝われた",
        "祝う",
        "お祝い",
        "天体",
        "センター",
        "百姓",
        "大脳",
        "式",
        "確実",
        "会長",
        "会長",
        "チャンピオン",
        "聖歌",
        "充電器",
        "慈善団体",
        "慈善団体",
        "チャーム",
        "魅力的な",
        "貞操",
        "チャタリング",
        "チェックリスト",
        "応援",
        "陽気な",
        "陽気",
        "応援",
        "NO TRANSLATION",
        "化学者",
        "大事な",
        "チェリー",
        "チーフテン",
        "子",
        "子供時代",
        "チャープ",
        "チゼル",
        "騎士道",
        "チョコレート",
        "選択",
        "合唱団",
        "合唱",
        "コーラス",
        "選ばれた",
        "チャウダー",
        "クロニクル",
        "含み笑い",
        "教会",
        "サイダー",
        "割礼",
        "市民",
        "市民",
        "礼儀",
        "文明",
        "文明化された",
        "透視的",
        "拍手する",
        "明らかにする",
        "クラシック",
        "クラシック",
        "古典",
        "分類する",
        "クリーン",
        "クリーニング",
        "清潔さ",
        "きれいに",
        "浄化する",
        "クレンジング",
        "クリアランス",
        "透明度",
        "事務的",
        "賢い",
        "賢い",
        "クライマックス",
        "親密さ",
        "閉鎖",
        "NO TRANSLATION",
        "ピエロ",
        "連合",
        "海岸",
        "共存する",
        "志願者",
        "認知",
        "コヒーレンス",
        "コヒーレントな",
        "粘着性の",
        "集合的に",
        "大佐",
        "巨大",
        "快適",
        "司令官",
        "指揮",
        "記念碑",
        "記念",
        "記念",
        "賞賛する",
        "立派な",
        "コメンテーター",
        "コミットした",
        "コモア",
        "連邦",
        "通信する",
        "コミュニケーション的",
        "聖体拝領",
        "コミュニティ",
        "転流",
        "通勤する",
        "コンパニオン",
        "思いやり",
        "思いやりのある",
        "互換性",
        "互換性のある",
        "説得力のある",
        "補償する",
        "代償",
        "能力",
        "コンピテンシー",
        "有能な",
        "自己満足",
        "補体",
        "相補的な",
        "完全に",
        "完全",
        "完了",
        "完了",
        "コンプライアンス",
        "準拠する",
        "NO TRANSLATION",
        "構成された",
        "作曲家",
        "落ち着き",
        "理解する",
        "包括的な",
        "同志",
        "同心円の",
        "調停",
        "結論",
        "コンコルド",
        "一致",
        "弔慰",
        "許す",
        "助ける",
        "導電性",
        "連合国",
        "信頼",
        "自信を持って",
        "確認済み",
        "適合",
        "味方の",
        "お祝い",
        "会衆",
        "合同",
        "愛好家",
        "良心",
        "良心的な",
        "意識",
        "奉献",
        "保全",
        "節約する",
        "かなりの",
        "思慮深い",
        "一貫性",
        "コンソール",
        "子音",
        "恒常",
        "定数",
        "憲法",
        "構成する",
        "完成品",
        "接触",
        "熟考",
        "コンテンツ",
        "持続する",
        "輪郭",
        "貢献する",
        "投稿者",
        "利便性",
        "便利",
        "修道院",
        "コンベンション",
        "精通",
        "会話",
        "変換する",
        "説得する",
        "クール",
        "冷たさ",
        "協力する",
        "協力する",
        "協力",
        "協力的",
        "コア",
        "戴冠",
        "株式会社",
        "体的",
        "矯正",
        "対応",
        "裏付ける",
        "コスモポリタン",
        "居心地の良い",
        "評議会",
        "弁護人",
        "カウンセラー",
        "カウント",
        "伯爵夫人",
        "勇気",
        "勇気のある",
        "丁寧",
        "礼儀",
        "求愛",
        "入り江",
        "契約",
        "受け台",
        "クラフト",
        "職人",
        "クリーム",
        "作成する",
        "創造的な",
        "信用",
        "信用証明書",
        "信頼性",
        "信頼できる",
        "クレジット",
        "NO TRANSLATION",
        "貸方",
        "クレッシェンド",
        "批判",
        "クラウニング",
        "重大な",
        "結晶",
        "抱きしめる",
        "料理",
        "頂点",
        "耕す",
        "栽培された",
        "栽培",
        "文化",
        "硬化可能な",
        "好奇心",
        "カール",
        "クッション",
        "顧客",
        "可愛い",
        "カッター",
        "デイム",
        "ダンス",
        "大胆",
        "ダーリン",
        "ダッシュ",
        "娘",
        "夜明け",
        "対処",
        "親愛な",
        "ディベート",
        "良識",
        "まともな",
        "宣言的",
        "献身",
        "守る",
        "守られた",
        "ディフェンダー",
        "防御する",
        "防衛",
        "尊敬",
        "決定的な",
        "度",
        "おいしい",
        "デリゲート",
        "審議する",
        "おいしい",
        "喜び",
        "喜んで",
        "楽しい",
        "救出",
        "配達",
        "民主主義",
        "実証可能な",
        "説明的な",
        "深さ",
        "記述的な",
        "値する",
        "〜に値する",
        "デザイナー",
        "望ましい",
        "望む",
        "望む",
        "先",
        "検出する",
        "検出",
        "決定",
        "決定",
        "開発する",
        "信心深い",
        "敬虔な",
        "器用",
        "ダイヤモンド",
        "日記",
        "辞書",
        "教訓的な",
        "食物",
        "威厳のある",
        "尊厳",
        "勤勉",
        "ディナー",
        "外交",
        "外交",
        "ディレクター",
        "発見",
        "NO TRANSLATION",
        "裁量",
        "自由裁量",
        "討論",
        "消毒",
        "処分する",
        "広める",
        "蒸留",
        "区別",
        "ちょっとした",
        "多様化する",
        "流用",
        "神性",
        "医師",
        "いじめ",
        "かわいい",
        "イルカ",
        "ドン",
        "寄付",
        "確かに",
        "鳩",
        "ダウンニー",
        "デュエット",
        "公爵",
        "耐久性",
        "耐久性のある",
        "忠実な",
        "熱心な",
        "意気込み",
        "伯爵",
        "獲得する",
        "熱心な",
        "熱心に",
        "熱心",
        "容易に",
        "区域",
        "NO TRANSLATION",
        "食べる",
        "エクスタシー",
        "恍惚な",
        "啓発",
        "教育する",
        "教育を受けた",
        "教育的",
        "効果的な",
        "効能",
        "効率",
        "効率的な",
        "努力",
        "射精",
        "精緻化",
        "嫌な",
        "長老",
        "長老たち",
        "選ぶ",
        "電気の",
        "電気",
        "優雅",
        "エレガント",
        "標高",
        "適格",
        "エリート",
        "雄弁",
        "雄弁",
        "解明する",
        "解放",
        "擁する",
        "名誉",
        "傑出した",
        "著名な",
        "著しく",
        "NO TRANSLATION",
        "共感",
        "力を与える",
        "エミュレートする",
        "有効にする",
        "有効化",
        "エンチャント",
        "エンチャンテッド",
        "魅惑的な",
        "NO TRANSLATION",
        "奨励します",
        "奨励",
        "百科事典",
        "努力",
        "与える",
        "付与された",
        "寄付",
        "耐久",
        "耐える",
        "エネルギッシュな",
        "従事する",
        "魅力的",
        "強化する",
        "楽しい",
        "楽しんで",
        "悟り",
        "啓発",
        "活気のある",
        "豊かに",
        "アンサンブル",
        "少尉",
        "進歩的な",
        "楽しむ",
        "楽しんだ",
        "面白い",
        "娯楽",
        "熱意",
        "愛好家",
        "NO TRANSLATION",
        "天体暦",
        "エピック",
        "典型的な",
        "平等",
        "均等に",
        "平衡",
        "株式",
        "使い",
        "エラディーテ",
        "エスプリト",
        "本質的な",
        "設立",
        "尊敬する",
        "美的",
        "倫理的な",
        "倫理",
        "常緑",
        "永遠の",
        "明らか",
        "進化",
        "高く評価する",
        "高揚",
        "高揚した",
        "超過する",
        "優れた",
        "優秀",
        "優れた",
        "交換",
        "興奮する",
        "励起",
        "エキサイト",
        "興奮した",
        "興奮",
        "エキサイティング",
        "典型的な",
        "免除",
        "爽快",
        "奨励",
        "勧告",
        "存在",
        "エキゾチック",
        "期待する",
        "期待",
        "便宜",
        "遠征",
        "経験豊富な",
        "専門家",
        "専門知識",
        "説明する",
        "絶妙",
        "絶妙に",
        "拡張する",
        "広範",
        "余分な",
        "特別な",
        "救出する",
        "盛り上がり",
        "容易にする",
        "事実",
        "学部",
        "NO TRANSLATION",
        "フェア",
        "かなり",
        "信仰",
        "忠実な",
        "名声",
        "身近な",
        "親しみやすさ",
        "有名な",
        "有名",
        "ファンシー",
        "ファンファーレ",
        "魅惑的な",
        "魅力",
        "ファッショナブルな",
        "無意味な",
        "有利な",
        "お気に入り",
        "好意主義",
        "恐れる",
        "偉業",
        "特徴",
        "致死率",
        "仲間",
        "フェローシップ",
        "女性",
        "肥沃な",
        "熱狂",
        "フェスティバル",
        "お祝い",
        "NO TRANSLATION",
        "忠実",
        "フィエスタ",
        "最後に",
        "完成品",
        "フィネス",
        "火の玉",
        "耐火",
        "堅さ",
        "NO TRANSLATION",
        "フィッティング",
        "治具",
        "お世辞",
        "艦隊",
        "柔軟性",
        "花",
        "フロー",
        "花",
        "流す",
        "飛行",
        "フォーカス",
        "愛情",
        "フード",
        "フットボール",
        "忍耐",
        "前",
        "先祖",
        "前の",
        "フォアマン",
        "先駆者",
        "予見する",
        "予見される",
        "先見の明",
        "フォージ",
        "許す",
        "許された",
        "許す",
        "形成的",
        "式",
        "NO TRANSLATION",
        "今後の",
        "強化する",
        "強迫",
        "要塞",
        "幸運な",
        "運",
        "前進",
        "見つけた",
        "財団",
        "香ばしい",
        "フランク",
        "率直",
        "兄弟",
        "自由",
        "自由に",
        "友人",
        "親切",
        "フレンドリーな",
        "友情",
        "激しい",
        "戯れる",
        "倹約",
        "実り多い",
        "満たす",
        "履行",
        "満員",
        "完全に",
        "楽しい",
        "基本的な",
        "ヒューズ",
        "融合",
        "利得",
        "獲得する",
        "勇敢な",
        "勇気",
        "豊富",
        "庭園",
        "ガーネット",
        "守備隊",
        "ガゼット",
        "ギヤ",
        "宝石",
        "一般",
        "寛大",
        "寛大な",
        "優しい",
        "天才",
        "優しい",
        "紳士",
        "優しさ",
        "ゲントリー",
        "純正",
        "ゼラニウム",
        "贈り物",
        "才能ある",
        "巨大",
        "ふざける",
        "桁",
        "与える",
        "うれしい",
        "喜び",
        "喜ぶ",
        "滑る",
        "一見",
        "輝く",
        "栄光",
        "賛美する",
        "栄光",
        "光沢",
        "輝き",
        "輝く",
        "神",
        "神聖な",
        "神様",
        "ゴールド",
        "良い",
        "よく",
        "良さ",
        "品",
        "のれん",
        "ゴージャスな",
        "福音",
        "支配する",
        "猶予",
        "優雅な",
        "優雅な",
        "優雅に",
        "卒業",
        "孫",
        "壮大",
        "祖母",
        "付与",
        "付与された",
        "感謝する",
        "満足",
        "感謝",
        "大きい",
        "偉大",
        "緑",
        "挨拶",
        "凶暴な",
        "微笑む",
        "手首",
        "グリット",
        "下地",
        "成長する",
        "成長",
        "保証",
        "ガード",
        "ガーディアン",
        "後見",
        "知事",
        "ガイダンス",
        "ガイド",
        "ガイドブック",
        "教祖",
        "ガッツ",
        "体操選手",
        "生息地",
        "ハレ",
        "ハンディ",
        "幸せに",
        "幸福",
        "ハッピー",
        "頑丈な",
        "調和よく",
        "調和",
        "収穫",
        "避難所",
        "前進",
        "癒し",
        "ヒーリング",
        "健康的な",
        "健康",
        "心のこもった",
        "ハース",
        "心から",
        "天",
        "天",
        "体重",
        "ヘルメット",
        "ヘルパー",
        "役に立つ",
        "ハーブ",
        "ヒーロー",
        "ヒロイック",
        "ヒーローズ",
        "ヒロイン",
        "ヒロイズム",
        "全盛期",
        "陽気な",
        "はしゃぎ",
        "雇う",
        "趣味",
        "休日",
        "聖なる",
        "聖なる",
        "敬意",
        "相同性",
        "正直な",
        "正直",
        "はちみつ",
        "ハネムーン",
        "名誉",
        "名誉ある",
        "希望",
        "希望",
        "地平線",
        "おもてなし",
        "家庭",
        "ハウスキーピング",
        "抱擁",
        "人道的",
        "人道的な",
        "人類",
        "謙虚な",
        "謙虚に",
        "謙虚",
        "ユーモスト",
        "ユーモラスな",
        "万歳",
        "畜産",
        "ハッシュ",
        "小屋",
        "衛生的な",
        "賛美歌",
        "理想主義",
        "アイドル",
        "NO TRANSLATION",
        "イルミネーション",
        "説明する",
        "著名な",
        "想像",
        "澄んだ",
        "巨大",
        "没頭する",
        "不滅の",
        "伝える",
        "公平",
        "公平",
        "完璧な",
        "不浸透性の",
        "重要度",
        "重要",
        "印象づける",
        "印象",
        "改善する",
        "改善された",
        "改善",
        "改善する",
        "即興",
        "譲ることができない",
        "就任",
        "鋭い",
        "含める",
        "含まれる",
        "を含む",
        "包括的な",
        "増加する",
        "消えない",
        "損害賠償",
        "独立",
        "不滅",
        "個性",
        "不屈の",
        "不可能な",
        "安価な",
        "間違いのない",
        "幼児",
        "無限",
        "無限",
        "影響力のある",
        "情報",
        "独創的な",
        "継承",
        "不可解な",
        "イノセンス",
        "無実",
        "無邪気に",
        "無害な",
        "革新的",
        "革新",
        "お問い合わせ",
        "問い合わせ",
        "好奇心",
        "不可分な",
        "記章",
        "インスペクタ",
        "インスピレーション",
        "インスピレーション",
        "インスピレーションを受けた",
        "本能的",
        "命令する",
        "命令",
        "インストラクター",
        "道具",
        "保証する",
        "損なわれていない",
        "完全性",
        "知性",
        "知的",
        "インテリジェンス",
        "インテリジェントな",
        "意図されました",
        "性交",
        "利子",
        "興味がある",
        "面白い",
        "インテリア",
        "対話",
        "間奏",
        "親密な",
        "イントネーション",
        "勇敢な",
        "直感",
        "直感的な",
        "いつも",
        "発明的な",
        "発明者",
        "調査する",
        "活気を与える",
        "招待",
        "招待する",
        "招待する",
        "鉄",
        "既約",
        "反駁できない",
        "大当たり",
        "ジャム",
        "NO TRANSLATION",
        "ジョブ",
        "参加する",
        "参加した",
        "ジョーカー",
        "冗談",
        "ジャーナリスト",
        "旅",
        "思いやりのある",
        "喜び",
        "楽しげ",
        "楽しい",
        "喜ばしい",
        "ジャンビリー",
        "司法",
        "賢明な",
        "ジャンプ",
        "正義",
        "正当",
        "正当化",
        "記念品",
        "ケン",
        "基調",
        "キーストーン",
        "種類",
        "親切",
        "同族",
        "キング",
        "キッス",
        "子猫",
        "仕掛け",
        "騎士",
        "知っている",
        "知識",
        "名声",
        "労働",
        "子羊",
        "土地",
        "着陸した",
        "レーザ",
        "賞賛できる",
        "笑い",
        "笑い",
        "笑い",
        "打ち上げ",
        "賞受賞者",
        "月桂樹",
        "月桂樹",
        "豪華な",
        "合法的",
        "鉛",
        "リーダー",
        "リーグ",
        "学ぶ",
        "学習",
        "講師",
        "余裕",
        "法的",
        "合法化された",
        "伝説の",
        "読みやすさ",
        "読みやすい",
        "余暇",
        "ゆっくりと",
        "補題",
        "寛大な",
        "レッスン",
        "文字通り",
        "レベル",
        "活用",
        "解放する",
        "解放",
        "自由",
        "としょうかん",
        "生命の血",
        "灯台",
        "好み",
        "言語学者",
        "ライオン",
        "リッテ",
        "論理的",
        "長寿",
        "君主",
        "愛らしい",
        "愛",
        "美しい",
        "NO TRANSLATION",
        "恋人",
        "愛する",
        "忠実な",
        "忠誠",
        "運",
        "幸運な",
        "甘美な",
        "光沢",
        "光沢のある",
        "贅沢な",
        "豪華な",
        "贅沢",
        "叙情詩",
        "叙情的な",
        "魔法の",
        "磁石",
        "磁気",
        "マグネタイト",
        "雄大",
        "壮大",
        "乙女",
        "メイン",
        "主力",
        "雄大な",
        "威厳",
        "メジャー",
        "多数",
        "管理する",
        "管理",
        "マンダリン",
        "男らしい",
        "現れた",
        "男らしい",
        "マナ",
        "マナー",
        "マナー",
        "メーカー",
        "行進",
        "マークされた",
        "市場性のある",
        "侯爵",
        "結婚",
        "骨髄",
        "結婚する",
        "マーシャル",
        "驚異",
        "素晴らしい",
        "驚くほど",
        "男性的",
        "マッサージ",
        "マスター",
        "傑作",
        "習熟",
        "メイト",
        "結婚",
        "マトロン",
        "最大",
        "市長",
        "草原",
        "測定された",
        "メダル",
        "仲介する",
        "調停",
        "メディエーター",
        "医療",
        "NO TRANSLATION",
        "地中海",
        "メドレー",
        "記念碑",
        "思い出深い",
        "補修",
        "月経",
        "指導者",
        "慈悲深い",
        "慈悲",
        "マージ",
        "値する",
        "功績のある",
        "楽しい",
        "メリー",
        "メトロポリタン",
        "卑劣な",
        "顕微鏡検査",
        "助産",
        "力強い",
        "マミ",
        "気になる",
        "思いやり",
        "省",
        "奇跡",
        "奇跡的な",
        "歓喜",
        "宣教師",
        "モデル",
        "中程度の",
        "モデレータ",
        "控えめな",
        "謙虚さ",
        "勢い",
        "金銭的な",
        "お金",
        "モンク",
        "記念碑",
        "道徳",
        "道徳",
        "道徳",
        "モルタル",
        "母性",
        "動機",
        "移動可能な",
        "ムーバー",
        "筋肉の",
        "音楽",
        "ミュージカル",
        "変更可能な",
        "相互",
        "昼寝",
        "自然主義者",
        "ナビゲート可能な",
        "きれいに",
        "ネクター",
        "針",
        "交渉する",
        "交渉者",
        "隣人",
        "神経",
        "ネスレ",
        "貴族",
        "ノーブル",
        "貴族",
        "指名",
        "正常",
        "注目すべき",
        "有名人",
        "NO TRANSLATION",
        "概念",
        "栄養",
        "数字",
        "ナース",
        "保育園",
        "育成",
        "栄養価の高い",
        "オーク",
        "オアシス",
        "誓い",
        "従順",
        "目的",
        "義務づける",
        "注意深い",
        "入手可能な",
        "明らか",
        "占有者",
        "職業",
        "占める",
        "提供",
        "役員",
        "オフセット",
        "オフショー",
        "全員",
        "開放性",
        "オペラ",
        "機会",
        "機会",
        "楽観",
        "楽観主義者",
        "オプション",
        "オプション",
        "オラクル",
        "演説",
        "オーケストラ",
        "任命された",
        "秩序ある",
        "奉仕",
        "オーガニック",
        "組織",
        "整理する",
        "組織された",
        "オーガズム",
        "独創",
        "装飾された",
        "華やかな",
        "結果",
        "アウトドア",
        "外側に",
        "大喜び",
        "圧倒的",
        "所有",
        "パシフィック",
        "パッド",
        "パディング",
        "パドル",
        "口当たりの良い",
        "緩和的",
        "万能薬",
        "腹部",
        "NO TRANSLATION",
        "パプリカ",
        "パラゴン",
        "パラマウント",
        "恩赦",
        "親子",
        "頭頂壁",
        "分かる",
        "参加",
        "パートナー",
        "パートナーシップ",
        "情熱",
        "情熱的な",
        "娯楽",
        "牧師",
        "ペストリー",
        "牧草地",
        "特許",
        "忍耐",
        "患者",
        "家長",
        "パトロン",
        "後援",
        "支払う",
        "平和",
        "平和な",
        "平和な",
        "孔雀",
        "ペック",
        "特色",
        "血統",
        "一見",
        "好きな",
        "知覚する",
        "知覚可能な",
        "多年生",
        "完璧な",
        "完璧",
        "出演者",
        "特典",
        "許可",
        "永久",
        "永続性",
        "永続的な",
        "個人的な",
        "関連する",
        "医薬品",
        "慈善事業者",
        "慈善事業",
        "哲学者",
        "フェニックス",
        "発音",
        "医師",
        "物理",
        "生理",
        "体格",
        "ピック",
        "ピクニック",
        "美しい",
        "信心深い",
        "ピル",
        "枕",
        "パイロット",
        "頂点",
        "パイオニア",
        "信心深い",
        "髄",
        "ピボット",
        "穏やかな",
        "プランニング",
        "遊び心のある",
        "遊び場",
        "劇場",
        "楽しい",
        "喜んだ",
        "楽しい",
        "約束",
        "プレナリー",
        "豊富",
        "叢",
        "梅",
        "鉛直",
        "ぬいぐるみ",
        "プライ",
        "尖った",
        "警察",
        "警官",
        "研磨",
        "磨かれた",
        "丁寧",
        "礼儀",
        "NO TRANSLATION",
        "プール",
        "法王",
        "人気",
        "普及した",
        "人口",
        "ポータブル",
        "所有する",
        "飲み物",
        "効力",
        "強力な",
        "強力に",
        "練習",
        "練習した",
        "練習",
        "賞賛",
        "賞賛された",
        "賞賛する",
        "祈る",
        "予防措置",
        "先行する",
        "優先順位",
        "貴重な",
        "正確",
        "精度",
        "偏見",
        "支配的",
        "抜群の",
        "好む",
        "プレミア",
        "施設",
        "準備する",
        "準備された",
        "先見の明",
        "存在",
        "プレゼント",
        "プレゼン可能な",
        "防腐剤",
        "保存する",
        "大統領",
        "威信",
        "プレスト",
        "かなり",
        "優先する",
        "防止",
        "貴重な",
        "誇り",
        "祭司",
        "神権",
        "聖職者",
        "優位",
        "一次",
        "プライム",
        "プライマー",
        "王子",
        "壮大な",
        "王女",
        "主要な",
        "原始的",
        "特権",
        "確信",
        "手順",
        "行列",
        "プロクター",
        "調達する",
        "驚異的な",
        "天才",
        "プロデューサー",
        "生産する",
        "製造",
        "生産的な",
        "生産性",
        "職業",
        "専門家",
        "教授",
        "熟練",
        "熟練",
        "大量の",
        "進捗",
        "進行",
        "プログレッシブ",
        "多分",
        "プロミネンス",
        "顕著に",
        "約束する",
        "有望",
        "プロモーション",
        "小道具",
        "適切な",
        "預言者",
        "予防的",
        "命題",
        "見通し",
        "繁栄する",
        "繁栄",
        "繁栄する",
        "保護する",
        "保護",
        "保護的な",
        "プロテクター",
        "誇りに思う",
        "証明する",
        "諺",
        "提供する",
        "提供する",
        "慎重",
        "慎重な",
        "詩篇",
        "パブリック",
        "引く",
        "説教壇",
        "定時の",
        "時間厳守",
        "子犬",
        "純粋に",
        "精製",
        "浄化する",
        "純粋主義者",
        "純度",
        "パル",
        "風変わりな",
        "修飾された",
        "予選",
        "クエスト",
        "質問",
        "クイックネス",
        "静止している",
        "静か",
        "キニーネ",
        "輝き",
        "放射性の",
        "放射する",
        "無線",
        "ラップ",
        "歓楽",
        "ラショナル",
        "リーダー",
        "容易に",
        "準備",
        "読書",
        "再確認する",
        "リアル",
        "理由",
        "安心",
        "安心する",
        "リベート",
        "再構築",
        "受け取った",
        "受信",
        "NO TRANSLATION",
        "往復",
        "埋め立て",
        "リクライニング",
        "認識可能な",
        "お勧めする",
        "和解",
        "再考",
        "再構築する",
        "再建",
        "レコーダー",
        "補充",
        "回復",
        "レクリエーション",
        "レクリエーション",
        "是正する",
        "償還",
        "救済",
        "リファイン",
        "洗練",
        "改革",
        "改革",
        "改質器",
        "さわやかな",
        "改装する",
        "リーガル",
        "摂政",
        "規則性",
        "調整する",
        "リハビリ",
        "リハビリ",
        "払い戻す",
        "払い戻し",
        "強化",
        "復活する",
        "喜ぶ",
        "喜び",
        "若返らせる",
        "若返らせた",
        "リラクゼーション",
        "関連する",
        "信頼性",
        "信頼性のある",
        "依存",
        "救済",
        "緩和",
        "リメイク",
        "顕著",
        "NO TRANSLATION",
        "救済",
        "寛解",
        "リフォーム",
        "ルネサンス",
        "レンダリングする",
        "更新",
        "改装する",
        "改装",
        "名声",
        "有名な",
        "再編成する",
        "賠償",
        "返済する",
        "悔い改める",
        "補充する",
        "充実した",
        "レポーター",
        "安息",
        "代表的な",
        "生殖",
        "評判の良い",
        "レスキュー",
        "予備",
        "居住者",
        "弾力のある",
        "抵抗性の",
        "断固として",
        "リソース",
        "尊敬",
        "尊敬",
        "立派な",
        "尊敬する",
        "尊敬する",
        "敬意",
        "猶予",
        "光り輝く",
        "責任ある",
        "応答性の",
        "残り",
        "安らかな",
        "反発",
        "修復する",
        "復元する",
        "拘束",
        "再開",
        "保持",
        "再会",
        "礼拝",
        "歓声",
        "敬老",
        "畏敬の念",
        "牧師",
        "悔い改め",
        "修正する",
        "復活",
        "革命的な",
        "褒賞",
        "リズム",
        "リズミカルな",
        "リボン",
        "豊か",
        "ライダー",
        "正義の",
        "正当な",
        "正しく",
        "熟した",
        "熟す",
        "上昇する",
        "リベット打ち",
        "ロードスター",
        "ロバストな",
        "岩",
        "ロッド",
        "曲がりくねった",
        "ロマンス",
        "ロマンチック",
        "ロマン主義",
        "ロープ",
        "根付いた",
        "バラ",
        "ロータ",
        "ルーチン",
        "ロイヤリティ",
        "ルーブリック",
        "ルース",
        "安全",
        "保障措置",
        "セージ",
        "聖人",
        "聖人",
        "給料",
        "顕著な",
        "有益な",
        "敬礼",
        "救い",
        "軟膏",
        "武士",
        "聖化",
        "神聖化する",
        "聖域",
        "楽しい",
        "サニタリー",
        "サテン",
        "満足に",
        "満足",
        "セーブ",
        "節約",
        "味わう",
        "おいしい",
        "精通した",
        "学者",
        "奨学金",
        "科学的",
        "科学者",
        "NO TRANSLATION",
        "スコア",
        "スクライブ",
        "スクリプト",
        "素晴らしい",
        "彫刻",
        "海",
        "シール",
        "味付け",
        "事務局",
        "年功",
        "センセーショナル",
        "センス",
        "感性",
        "賢明に",
        "官能",
        "官能的な",
        "センチメンタル",
        "感傷",
        "センチネル",
        "静寂",
        "説教",
        "血清",
        "セトラー",
        "セックス",
        "形状",
        "綿密に",
        "シェア",
        "シェルター",
        "羊飼い",
        "輝く",
        "シャイニング",
        "ショッピング",
        "ショルダー",
        "賢い",
        "シルク",
        "簡略化する",
        "誠実",
        "誠実",
        "歌う",
        "単独で",
        "サー",
        "姉妹",
        "熟練",
        "巧みな",
        "空",
        "スレート",
        "洗練された",
        "細い",
        "スリム",
        "スマイル",
        "笑う",
        "打ち負かす",
        "滑らかさ",
        "スニッカー",
        "酒精",
        "社交的",
        "慰め",
        "兵士",
        "固体",
        "固い",
        "溶液",
        "ソルベンシー",
        "ソナー",
        "ソナタ",
        "ソネット",
        "素晴らしい",
        "落ち着かせる",
        "癒しの",
        "NO TRANSLATION",
        "健全性",
        "スープ",
        "スパ",
        "広々とした",
        "スパニエル",
        "輝く",
        "特別",
        "NO TRANSLATION",
        "スピーチ",
        "スピーディ",
        "つづり",
        "スパイス",
        "精神",
        "スピリッツ",
        "素晴らしい",
        "素晴らしい",
        "スポンサー",
        "スポットなし",
        "配偶者",
        "スプルース",
        "安定した",
        "スタッカート",
        "ステンレス",
        "種馬",
        "忠実な",
        "スタミナ",
        "立っている",
        "星",
        "スターライト",
        "星空",
        "堂々たる",
        "ステートメント",
        "像",
        "状態",
        "頑張る",
        "不動の",
        "恒星",
        "スチュワード",
        "静止",
        "格納",
        "簡単",
        "戦略的",
        "ストラテジスト",
        "力",
        "強化する",
        "強化",
        "印象的な",
        "印象的",
        "強く",
        "構造",
        "スタッド",
        "調査",
        "頑丈",
        "昇華",
        "物質",
        "実質的な",
        "成功する",
        "成功する",
        "成功",
        "成功した",
        "簡潔な",
        "十分",
        "シュガー",
        "適切な",
        "蒸し暑い",
        "太陽",
        "晴れた",
        "日没",
        "日光",
        "素晴らしいです",
        "超人",
        "優れました",
        "優位",
        "スーパーマン",
        "スーパースター",
        "嘆願",
        "用品",
        "供給",
        "サポートされる",
        "サポーター",
        "サポートする",
        "最高",
        "最高に",
        "保証人",
        "推測",
        "凌駕する",
        "驚き",
        "測量",
        "生き残ります",
        "誓う",
        "甘い",
        "恋人",
        "恋人",
        "甘味",
        "お菓子",
        "迅速",
        "泳ぐ",
        "シンボリック",
        "対称",
        "対称",
        "同情的な",
        "同情",
        "交響曲",
        "同期する",
        "相乗的な",
        "会議",
        "タクト",
        "物語",
        "才能",
        "お守り",
        "トーク",
        "日焼けした",
        "仕事",
        "味わい深い",
        "おいしい",
        "教える",
        "先生",
        "技術",
        "禁酒",
        "温かく",
        "テナブル",
        "強引な",
        "強靭性",
        "テナント",
        "テナント",
        "入札",
        "優しさ",
        "感謝している",
        "感謝祭",
        "理論的",
        "治療的",
        "治療薬",
        "NO TRANSLATION",
        "サラブレッド",
        "思慮深い",
        "思いやり",
        "倹約",
        "スリル",
        "スリリング",
        "繁栄する",
        "王位",
        "くすぐる",
        "タイリング",
        "タイムリーな",
        "錦糸",
        "タイトル",
        "トースト",
        "耐性のある",
        "耐性",
        "上",
        "靭性",
        "タワー",
        "優しく",
        "伝統的な",
        "静かな",
        "静けさ",
        "超越",
        "超越的",
        "旅行",
        "宝",
        "木",
        "驚くほど",
        "傾向",
        "トレンディな",
        "支流",
        "トリビュート",
        "三角",
        "勝利",
        "勝利する",
        "トロフィー",
        "休戦",
        "真",
        "信頼できる",
        "真実",
        "真実",
        "守備",
        "家庭教師",
        "ツイン",
        "つぶやく",
        "最終的に",
        "審判",
        "一貫",
        "全会一致",
        "思いやりのある",
        "不偏",
        "破られない",
        "破られていない",
        "拘束されていない",
        "下線",
        "理解",
        "引き受ける",
        "分割されていない",
        "不滅",
        "明白に",
        "展開する",
        "統一",
        "均一に",
        "感染していない",
        "ユニークな",
        "ユニゾン",
        "ユニタリー",
        "ユナイテッド",
        "統一",
        "大学",
        "無制限",
        "気取らない",
        "疑いのない",
        "疑いなく",
        "疑いのない",
        "無傷",
        "非自己",
        "抜群の",
        "揺るがない",
        "隆起",
        "直立",
        "使いやすさ",
        "案内人",
        "通常の",
        "ユーティリティー",
        "ユートピア",
        "休暇",
        "ワクチン",
        "勇敢な",
        "NO TRANSLATION",
        "貴重な",
        "前衛",
        "征服する",
        "ベルベット",
        "ベルベット",
        "由緒ある",
        "尊敬",
        "真実",
        "青々とした",
        "検証",
        "確認済み",
        "本当に",
        "誠実な",
        "春",
        "生きる",
        "ベテラン",
        "ディケール",
        "ビクター",
        "勝利する",
        "勝利",
        "警戒",
        "警戒する",
        "活力",
        "激しい",
        "村人",
        "弁別",
        "弁護",
        "バージン",
        "処女",
        "美徳",
        "善良な",
        "ビジョン",
        "先見の明",
        "訪問",
        "ビジター",
        "重要な",
        "活力",
        "活気のある",
        "鮮やかな",
        "単語",
        "ボランティア",
        "気持ちの良い",
        "保証",
        "誓い",
        "賃金",
        "保証",
        "戦士",
        "ウォッチドッグ",
        "注意深い",
        "ウォッチマン",
        "防水",
        "富",
        "耐候性",
        "歓迎",
        "白",
        "白",
        "健全",
        "ウィッケット",
        "広範囲",
        "喜んで",
        "意欲",
        "棚ぼた",
        "勝者",
        "勝つ",
        "賞金",
        "無線",
        "ウィス",
        "知恵",
        "賢い",
        "ウィット",
        "耐える",
        "知恵",
        "気分",
        "ウィザード",
        "子宮",
        "素晴らしい",
        "すばらしい",
        "不思議な",
        "ワード",
        "ワーキング",
        "崇拝",
        "価値",
        "価値がある",
        "無駄",
        "ライター",
        "若い",
        "若い",
        "若者",
        "熱意",
        "熱心な",
        "熱意",
    ]
)

_negative = set(
    [
        "放棄する",
        "放棄された",
        "放棄",
        "拉致",
        "異常な",
        "収差",
        "嫌う",
        "忌まわしい",
        "暴力",
        "異常な",
        "廃止する",
        "廃止",
        "忌み嫌う",
        "嫌悪",
        "アボート",
        "中絶",
        "不完全な",
        "摩耗",
        "廃止する",
        "膿瘍",
        "不在",
        "不在",
        "不在者",
        "欠勤",
        "不条理な",
        "不条理",
        "乱用",
        "深刻な",
        "深淵",
        "事故",
        "偶然",
        "呪われた",
        "告発",
        "反論的",
        "告発された",
        "告発者",
        "非難する",
        "痛み",
        "痛む",
        "酸",
        "実行可能な",
        "加算器",
        "中毒",
        "脂肪",
        "裁定する",
        "訓戒",
        "漂流する",
        "混入した",
        "姦通",
        "敵",
        "有害な",
        "逆境",
        "苦しめる",
        "悩んでいる",
        "苦しみ",
        "侮辱",
        "恐れ",
        "余波",
        "後味",
        "悪化した",
        "悪化する",
        "悪化",
        "侵略",
        "積極的な",
        "侵略者",
        "ああ",
        "かき混ぜた",
        "攪拌",
        "苦しむ",
        "苦しみ",
        "荒れ地",
        "アイル",
        "病気の",
        "無意味な",
        "空気",
        "警報",
        "警戒する",
        "アルコール依存症",
        "エイリアン",
        "疎外",
        "疎外された",
        "疎外",
        "代謝",
        "申し立て",
        "主張する",
        "全員",
        "言論",
        "あいまいな",
        "待ち伏せ",
        "健忘症",
        "アンフェタミン",
        "アナコンダ",
        "肛門",
        "アナキズム",
        "アナキスト",
        "アナーキー",
        "嫌悪",
        "古代",
        "怒り",
        "狭心症",
        "釣り",
        "怒っている",
        "苦悩",
        "敵意",
        "アニミス",
        "全滅させる",
        "絶滅した",
        "消滅",
        "悩ます",
        "煩わしさ",
        "迷惑な",
        "廃止する",
        "廃止",
        "異常",
        "匿名",
        "拮抗",
        "アンタゴニスト",
        "敵対的",
        "炭疽",
        "赤ちゃん",
        "反感",
        "古くなった",
        "反社会的",
        "アンチテーゼ",
        "不安",
        "不安",
        "アパッチ",
        "無愛想",
        "無関心",
        "アブラムシ",
        "ぞっとする",
        "虫垂炎",
        "不安",
        "恐ろしい",
        "予算",
        "アルカイック",
        "つらい",
        "主張する",
        "引数",
        "議論的な",
        "乾燥",
        "軍備",
        "裁判",
        "延滞",
        "逮捕",
        "傲慢",
        "傲慢な",
        "砒素",
        "放火",
        "砲兵",
        "灰",
        "恥ずかしい",
        "灰",
        "お尻",
        "襲撃",
        "加害者",
        "暗殺者",
        "暗殺する",
        "暗殺",
        "暴行",
        "下衆野郎",
        "迷う",
        "収斂",
        "亡命",
        "無神論",
        "アテローム性動脈硬化症",
        "ひどい",
        "残虐行為",
        "萎縮",
        "攻撃",
        "攻撃",
        "減衰した",
        "減衰",
        "大胆",
        "厳しい",
        "緊縮",
        "独裁的な",
        "剖検",
        "雪崩",
        "貪欲",
        "復讐者",
        "嫌う",
        "嫌悪",
        "避ける",
        "回避",
        "ひどい",
        "ぎこちなさ",
        "失敗",
        "手を振る",
        "ふざける",
        "ヒヒ",
        "後方に",
        "後方に",
        "バックウォーター",
        "細菌",
        "NO TRANSLATION",
        "悪い",
        "狸",
        "ひどく",
        "不良",
        "執行猶予",
        "餌",
        "ベール",
        "ボーク",
        "NO TRANSLATION",
        "強盗",
        "ベーン",
        "強打",
        "バンガー",
        "追い払う",
        "追放された",
        "追放",
        "破産",
        "倒産",
        "バンシー",
        "かっこ",
        "野蛮人",
        "野蛮な",
        "野蛮主義",
        "樹皮",
        "禁止",
        "不毛",
        "バリケード",
        "バリア",
        "根拠のない",
        "クソ野郎",
        "バター",
        "殴られた",
        "電池",
        "戦い",
        "戦った",
        "戦場",
        "ボウディ",
        "バヨネット",
        "ベアラー",
        "獣",
        "獣医",
        "打つ",
        "倒れる",
        "請う",
        "乞食",
        "乞う",
        "巨人",
        "見守る",
        "遅れた",
        "卑劣な",
        "交戦国",
        "ベルト",
        "ベンダー",
        "遺族",
        "死別",
        "ベレフト",
        "凶暴な",
        "獣医",
        "裏切る",
        "裏切り",
        "注意する",
        "困惑",
        "バイアス",
        "偏った",
        "喧嘩",
        "NO TRANSLATION",
        "ぞんざい",
        "股間",
        "胆汁",
        "生検",
        "バーチ",
        "発祥の地",
        "雌犬",
        "一口",
        "激しく",
        "苦味",
        "奇妙な",
        "黒",
        "ブラックジャック",
        "脅迫",
        "黒さ",
        "責任",
        "まばゆい",
        "冒涜的な",
        "冒涜",
        "爆風",
        "ぼんやりした",
        "ふざける",
        "燃える",
        "荒涼",
        "出血",
        "傷つける",
        "疫病",
        "荒れた",
        "ブラインド",
        "盲目",
        "盲目的に",
        "失明",
        "ブリスター",
        "肥大",
        "ブロブ",
        "封鎖",
        "流血",
        "血まみれの",
        "血まみれの",
        "ブロット",
        "送風機",
        "吹き消す",
        "ブルース",
        "ブラフ",
        "大失敗",
        "ぼかし",
        "ぼやけた",
        "赤面",
        "自慢する",
        "沼地",
        "偽",
        "煮る",
        "ボイラープレート",
        "爆弾",
        "ボンバード",
        "砲撃",
        "爆撃された",
        "束縛",
        "債券",
        "ブー",
        "ブービー",
        "酒",
        "NO TRANSLATION",
        "退屈",
        "退屈な",
        "借り手",
        "気にする",
        "気になる",
        "下",
        "バウンド",
        "試合",
        "ウシ",
        "男の子",
        "ボイコット",
        "自慢",
        "ブランデー",
        "勇敢な",
        "喧嘩",
        "厚かましい",
        "違反",
        "壊す",
        "激しい",
        "NO TRANSLATION",
        "賄賂",
        "贈収賄",
        "旅団",
        "ブリムストーン",
        "剛毛",
        "広大な側面",
        "焼く",
        "壊れた",
        "壊れた",
        "売春宿",
        "打撲傷",
        "鋭い",
        "残忍な",
        "残忍",
        "ブルート",
        "ビュッフェ",
        "バグ",
        "NO TRANSLATION",
        "球根の",
        "いじめ",
        "駄目",
        "バマー",
        "負担",
        "官僚",
        "官僚",
        "泥棒",
        "強盗",
        "埋葬",
        "埋葬された",
        "バーク",
        "焼けた",
        "逮捕された",
        "肉屋",
        "バット",
        "騒がれた",
        "カバル",
        "不協和音",
        "CAD",
        "死体",
        "ケージ",
        "計算する",
        "NO TRANSLATION",
        "コール",
        "キャンペーン",
        "キャンセル",
        "癌",
        "潰瘍",
        "食堂",
        "共食い",
        "NO TRANSLATION",
        "捕虜",
        "捕虜",
        "捕獲者",
        "キャプチャー",
        "カーカス",
        "癌腫",
        "心筋症",
        "不注意",
        "風刺画",
        "虫歯",
        "大虐殺",
        "肉体",
        "肉食性の",
        "カルテル",
        "場合",
        "棺",
        "カースト",
        "犠牲者",
        "白内障",
        "災害",
        "カテーテル",
        "注意",
        "セド",
        "墓地",
        "検閲",
        "非難",
        "セス",
        "停止",
        "チャフ",
        "擦り傷",
        "悪魔",
        "チャレンジ",
        "混沌",
        "混沌としました",
        "シャレード",
        "有料",
        "追跡",
        "懲罰",
        "おしゃべり",
        "安いです",
        "カンニング",
        "チーズケーキ",
        "シケイン",
        "子供っぽい",
        "肌寒い",
        "クロロホルム",
        "チョーク",
        "コレラ",
        "チョップ",
        "雑用",
        "慢性の",
        "シガレット",
        "騒ぎ",
        "衝突",
        "衝突",
        "爪",
        "回廊",
        "曇った",
        "曇り",
        "塊",
        "不器用な",
        "コカイン",
        "強姦",
        "強要",
        "棺",
        "コールド",
        "冷たく",
        "寒さ",
        "疝痛",
        "崩壊",
        "衝突",
        "共謀",
        "コマ",
        "昏睡",
        "戦闘",
        "戦闘員",
        "戦闘的",
        "コミット",
        "騒ぎ",
        "共産主義",
        "共産主義者",
        "コンペ",
        "文句を言う",
        "苦情",
        "錯化された",
        "複雑",
        "複雑にする",
        "複雑な",
        "合併症",
        "堆肥",
        "強制",
        "強制",
        "隠す",
        "隠蔽された",
        "隠蔽",
        "うぬぼれ",
        "思いやりのある",
        "脳震盪",
        "非難する",
        "非難",
        "勘違いする",
        "軽蔑",
        "告白",
        "閉じ込める",
        "閉じ込められた",
        "閉じ込め",
        "没収する",
        "没収",
        "火災",
        "紛争",
        "矛盾する",
        "混乱する",
        "混乱した",
        "混乱させる",
        "混乱",
        "混雑",
        "思い通りの",
        "征服",
        "共謀者",
        "共謀する",
        "驚き",
        "便秘",
        "制約する",
        "拘束された",
        "制約",
        "伝染",
        "伝染する",
        "汚染する",
        "汚染された",
        "汚染",
        "軽蔑",
        "軽蔑的な",
        "軽蔑的な",
        "争う",
        "密輸品",
        "契約した",
        "矛盾する",
        "矛盾",
        "矛盾する",
        "反対の",
        "対比",
        "違反",
        "違反",
        "議論の余地のある",
        "論争",
        "罪を犯す",
        "信念",
        "コープ",
        "コピー",
        "コピーキャット",
        "コロナ",
        "伍長",
        "死体",
        "補正",
        "腐食",
        "腐食性の",
        "破損した",
        "腐敗する",
        "腐敗",
        "咳",
        "カウンセラー",
        "コースニング",
        "探検する",
        "臆病者",
        "臆病",
        "臆病な",
        "カニ",
        "亀裂",
        "割れた",
        "クラッキング",
        "けいれん",
        "窮屈な",
        "クランク",
        "不気味な",
        "ひどい",
        "クラッシュ",
        "クロール",
        "狂った",
        "狂った",
        "ぎこちない",
        "生き物",
        "クリープ",
        "犯罪",
        "犯罪者",
        "犯罪",
        "うんざりする",
        "窮屈な",
        "不自由な",
        "危機",
        "鮮明",
        "評論家",
        "批判",
        "批判する",
        "詐欺",
        "クロス",
        "股間",
        "十字架",
        "十字架",
        "原油",
        "残酷な",
        "残酷に",
        "残酷",
        "崩壊する",
        "クランチ",
        "十字軍",
        "破砕されました",
        "粉砕する",
        "痂皮",
        "泣く",
        "泣く",
        "陰謀",
        "カッコウッド",
        "鳩",
        "切る",
        "犯罪性",
        "犯罪者",
        "犯人",
        "カルト",
        "面倒",
        "カッピング",
        "カール",
        "呪い",
        "呪われた",
        "呪い",
        "小物",
        "カッター",
        "卑劣な",
        "切断",
        "シアン化物",
        "サイクロン",
        "嚢胞",
        "サイトメガロウイルス",
        "ダブリング",
        "デーモン",
        "怪物",
        "短剣",
        "損傷",
        "損害",
        "くそー",
        "間違い",
        "卑劣な",
        "ダンパー",
        "ふけ",
        "ダンディー",
        "危険",
        "危険な",
        "暗く",
        "暗くなった",
        "闇",
        "破線",
        "荒々しく",
        "ぼんやりした",
        "非アクティブ化する",
        "デッドロック",
        "致命的",
        "聴覚障害者",
        "死",
        "大失敗",
        "放蕩",
        "デブリ",
        "債務",
        "債務者",
        "減衰",
        "腐った",
        "故人",
        "詐欺",
        "欺く",
        "欺く",
        "騙された",
        "欺く",
        "欺瞞",
        "偽りの",
        "偏位",
        "低下",
        "衰退する",
        "分解",
        "減少",
        "デクリメント",
        "老朽化した",
        "デクリ",
        "差し引く",
        "名誉毀損",
        "名誉毀損",
        "デフォルト",
        "敗北",
        "敗北した",
        "欠陥",
        "NO TRANSLATION",
        "欠陥のある",
        "無防備",
        "延期する",
        "反抗",
        "反抗的",
        "欠乏",
        "赤字",
        "収縮する",
        "デフレ",
        "変形する",
        "変形した",
        "変形",
        "欺瞞",
        "失われた",
        "無視する",
        "縮退",
        "縮退する",
        "分解",
        "劣化する",
        "劣化する",
        "ディレイ",
        "遅延",
        "有害な",
        "削除",
        "非行",
        "延滞",
        "狂った",
        "せん妄",
        "大洪水",
        "妄想",
        "妄想",
        "デマンド",
        "要求の厳しい",
        "痴呆",
        "痴呆",
        "没する",
        "解体する",
        "解体",
        "悪魔",
        "悪魔的な",
        "腐った",
        "拒否",
        "否定された",
        "告発する",
        "放棄",
        "否定する",
        "否定する",
        "出発した",
        "出発",
        "依存",
        "依存",
        "嘆かわしい",
        "嘆かわしい",
        "追放",
        "追放",
        "堕落した",
        "堕落",
        "減価償却する",
        "減価償却された",
        "減価償却費",
        "落ち込む",
        "落ち込んだ",
        "落ち込む",
        "うつ病",
        "抑うつ",
        "剥奪",
        "混乱した",
        "孤立した",
        "嘲り",
        "逸脱",
        "侮辱的な",
        "冒涜",
        "砂漠",
        "捨てられた",
        "脱走",
        "断る",
        "荒廃",
        "絶望",
        "絶望する",
        "絶望的な",
        "卑劣な",
        "NO TRANSLATION",
        "独裁的な",
        "専制主義",
        "貧しい",
        "破壊されました",
        "駆逐艦",
        "破壊",
        "破壊",
        "破壊的",
        "離脱",
        "抑留する",
        "抑留者",
        "留置",
        "劣化する",
        "劣化した",
        "劣化",
        "嫌う",
        "爆発する",
        "低下させる",
        "損害",
        "有害な",
        "デトリタス",
        "荒廃する",
        "壊滅的な",
        "荒廃",
        "悪魔",
        "悪質な",
        "邪悪な",
        "偏重",
        "食べる",
        "悪魔的な",
        "診断",
        "告発する",
        "独裁者",
        "独裁者",
        "独裁",
        "NO TRANSLATION",
        "困難",
        "困難",
        "脱走",
        "荒廃した",
        "希薄",
        "消える",
        "減少した",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "泥",
        "汚れた",
        "障害",
        "無効にする",
        "無効",
        "不満",
        "同意しない",
        "同意しない",
        "不一致",
        "許可されていない",
        "失望する",
        "失望した",
        "失望する",
        "失望",
        "不承認",
        "不承認",
        "不承認",
        "不承認",
        "災害",
        "悲惨な",
        "信じない",
        "破棄",
        "放電",
        "規律",
        "放棄する",
        "変色",
        "変色した",
        "不快",
        "切断する",
        "切断された",
        "断線",
        "不満",
        "中止します",
        "不連続",
        "不和",
        "落胆する",
        "落胆",
        "信用できない",
        "差別する",
        "弁別する",
        "差別",
        "軽蔑",
        "疾患",
        "病気の",
        "体外",
        "離脱",
        "醜い",
        "恥ずべき",
        "NO TRANSLATION",
        "恥ずべき",
        "不満",
        "嫌悪",
        "嫌な",
        "落胆した",
        "気を失う",
        "不正直な",
        "不正",
        "不名誉",
        "幻滅",
        "虚偽情報",
        "不誠実な",
        "崩壊する",
        "崩壊",
        "無関心な",
        "嫌い",
        "嫌いな",
        "転位",
        "陰鬱な",
        "うんざりする",
        "断頭",
        "解任",
        "不従順",
        "不従順な",
        "不従順な",
        "障害",
        "無秩序な",
        "混乱した",
        "卑劣な",
        "卑劣な",
        "不一致",
        "思いやりのある",
        "払拭する",
        "分散",
        "置換する",
        "不快な",
        "不快",
        "廃棄",
        "放棄された",
        "紛争",
        "失格",
        "失格",
        "失格",
        "無視",
        "無視する",
        "評判の悪い",
        "無礼な",
        "無礼な",
        "混乱",
        "不満",
        "不平",
        "反対する",
        "失礼",
        "反論する",
        "溶解",
        "不協和音",
        "嫌悪",
        "嫌な",
        "歪",
        "ねじれ",
        "気をそらす",
        "気を散らす",
        "気を散らす",
        "気晴らし",
        "びっくりする",
        "苦痛",
        "苦しい",
        "悲惨な",
        "不信",
        "外乱",
        "邪魔された",
        "使用しない",
        "未使用",
        "発散する",
        "分割された",
        "売却",
        "離婚",
        "めまい",
        "めまい",
        "ドッキング",
        "NO TRANSLATION",
        "減速",
        "ドール",
        "NO TRANSLATION",
        "支配的",
        "支配",
        "ロバ",
        "いたずら書き",
        "運命",
        "運命の",
        "最悪の日",
        "疑問に思う",
        "疑わしい",
        "疑う",
        "寝る",
        "〜する",
        "落ちる",
        "卑劣な",
        "排水",
        "欠点",
        "恐怖",
        "恐ろしい",
        "恐ろしい",
        "荒々しい",
        "飲酒",
        "駆け落ち",
        "無人機",
        "垂れ下がる",
        "干ばつ",
        "溺れる",
        "眠気",
        "ぎこちない",
        "酔っぱらい",
        "酩酊",
        "疑わしい",
        "鈍い",
        "ダム",
        "ダミー",
        "ダンプ",
        "ダン",
        "ダンジョン",
        "二重",
        "二枚舌",
        "強迫",
        "ほこり",
        "矮小",
        "死んでいる",
        "赤痢",
        "地震",
        "盗聴",
        "布告",
        "ザーメン",
        "自発的",
        "大変な",
        "イジェクトする",
        "排出",
        "排除",
        "見つけにくい",
        "衰弱した",
        "NO TRANSLATION",
        "恥ずかしい",
        "恥ずかしい",
        "恥ずかしさ",
        "横領",
        "塞栓症",
        "混乱した",
        "緊急",
        "エンクレーブ",
        "浸食",
        "妨害",
        "危険",
        "絶滅危惧種",
        "風土病",
        "敵",
        "執行",
        "謎めいた",
        "敵意",
        "奴隷",
        "奴隷にされた",
        "奴隷化",
        "もつれた",
        "エンタングルメント",
        "内柵",
        "嫉妬深い",
        "流行",
        "てんかん",
        "根絶する",
        "根絶",
        "消去する",
        "侵食",
        "間違い",
        "誤った",
        "不安定な",
        "エラッタム",
        "間違った",
        "エラー",
        "爆発する",
        "噴火",
        "エスカレート",
        "避ける",
        "スパイ活動",
        "疎遠な",
        "安楽死",
        "避難させる",
        "避難",
        "回避する",
        "回避",
        "追放",
        "追放",
        "悪の",
        "悪化させる",
        "悪化",
        "厳しい",
        "誇張する",
        "誇張した",
        "検査",
        "怒り",
        "発掘",
        "過剰",
        "消費税",
        "除外された",
        "除外",
        "除外",
        "排泄物",
        "悲惨な",
        "言い訳",
        "実行",
        "実行者",
        "排気",
        "疲れた",
        "疲労",
        "NO TRANSLATION",
        "亡命",
        "エクソシズム",
        "駐在員",
        "追放",
        "支出",
        "経費",
        "失効する",
        "失効した",
        "卑猥な",
        "爆発する",
        "爆発",
        "爆発物",
        "露出した",
        "収用",
        "追放",
        "駆除する",
        "絶滅",
        "絶滅した",
        "消す",
        "裁判外",
        "端",
        "製作する",
        "製造",
        "フェード",
        "糞便",
        "失敗する",
        "失敗",
        "失神",
        "信じられない",
        "偽",
        "秋",
        "間違った",
        "誤解",
        "虚弱",
        "落下",
        "休閑",
        "虚偽",
        "虚偽",
        "改ざん",
        "偽造する",
        "虚偽",
        "震える",
        "飢饉",
        "狂信的な",
        "茶番",
        "遠い",
        "断食",
        "脂肪",
        "致命的な",
        "死亡",
        "運命",
        "疲労",
        "疲れた",
        "脂肪",
        "不具合",
        "欠陥のある",
        "フォーン",
        "恐れ",
        "恐ろしい",
        "恐ろしい",
        "恐れる",
        "発熱性の",
        "糞便",
        "糞便",
        "費用",
        "弱い",
        "偽りの",
        "落ちた",
        "フェローン",
        "重罪",
        "発酵",
        "猛烈な",
        "獰猛",
        "フェッド",
        "封建",
        "封建主義",
        "熱くなる",
        "大失敗",
        "フィブス",
        "気まぐれな",
        "架空の",
        "悪魔",
        "激しい",
        "戦い",
        "戦う",
        "ろう者",
        "汚物",
        "汚い",
        "銃器",
        "フィット",
        "ふわふわした",
        "弛緩",
        "フラグを立てる",
        "深刻な",
        "フレーク",
        "フラップ",
        "鼓腸",
        "誇示する",
        "欠陥",
        "ノミ",
        "NO TRANSLATION",
        "フリース",
        "肉質の",
        "フリンチング",
        "鞭打ち",
        "フロップ",
        "ヒラメ",
        "インフルエンザ",
        "変動",
        "敵",
        "挫折した",
        "愚かな",
        "ばか",
        "愚かな",
        "愚かさ",
        "飼料",
        "募集",
        "禁じる",
        "禁止する",
        "力",
        "強制された",
        "強制的に",
        "予言",
        "差し押さえ",
        "忘れる",
        "外国人",
        "外国人",
        "前もって警告された",
        "失う",
        "失効した",
        "没収",
        "偽造",
        "忘れる",
        "忘れた",
        "忘れ去られた",
        "無形",
        "姦淫",
        "見捨てる",
        "忘れ去られた",
        "ファウル",
        "骨折",
        "壊れやすい",
        "虚弱",
        "必死の",
        "詐欺",
        "詐欺",
        "恐るべき",
        "ほつれ",
        "擦り切れた",
        "奇妙な",
        "凍結",
        "熱狂的な",
        "狂った",
        "熱狂",
        "フレット",
        "恐怖",
        "怖がる",
        "恐れた",
        "恐ろしい",
        "寒い",
        "軽薄",
        "凍傷",
        "泡",
        "眉をひそめる",
        "悩む",
        "果実のない",
        "挫折",
        "挫折した",
        "欲求不満",
        "ファッジ",
        "逃亡者",
        "振る舞う",
        "ヒューム",
        "発煙",
        "真菌",
        "ファンク",
        "激怒する",
        "風邪",
        "怒り",
        "大騒ぎ",
        "うるさい",
        "無益な",
        "無益",
        "ギャビー",
        "ギャグ",
        "胆汁",
        "教授",
        "ギャンブル",
        "ギャンブラー",
        "ギャンブル",
        "ギャング",
        "監獄",
        "ギャップ",
        "ゴミ",
        "光り輝く",
        "ガーニッシュ",
        "ガッシュ",
        "ガツピア",
        "NO TRANSLATION",
        "夢中",
        "紳士",
        "老人",
        "恐ろしい",
        "ゲットー",
        "幽霊",
        "うんざりする",
        "氷河",
        "グレア",
        "目立つ",
        "グライブ",
        "憂鬱",
        "暗い",
        "くず",
        "過剰",
        "大食い",
        "グノーム",
        "ゴブリン",
        "無神経",
        "淋病",
        "グー",
        "ゴア",
        "峡谷",
        "ゴリラ",
        "深刻な",
        "ゴシップ",
        "ガウジ",
        "痛風",
        "政府",
        "つかむ",
        "つかむ",
        "火格子",
        "すりおろし",
        "格子",
        "墓",
        "貪欲",
        "貪欲",
        "手榴弾",
        "悲しみ",
        "苦情",
        "悲しむ",
        "悲しい",
        "恐るべき",
        "汚れた",
        "汚れた",
        "研削",
        "激しく",
        "グリズリー",
        "声援",
        "NO TRANSLATION",
        "キモい",
        "グロテスク",
        "接地された",
        "根拠のない",
        "うなり声",
        "うなる",
        "恨み",
        "恨んで",
        "ぞっとする",
        "ぞっとする",
        "不平を言う",
        "ひどい",
        "ゲリラ",
        "邪悪な",
        "ギロチン",
        "罪悪感",
        "有罪",
        "見せかけた",
        "ガル",
        "嫌な",
        "銃",
        "吐き出す",
        "騒ぎ",
        "ジプシー",
        "ハグ",
        "皮肉な",
        "毛深い",
        "中途半端",
        "幻覚",
        "ホルター",
        "停止する",
        "邪魔する",
        "ハムストリング",
        "ハンディキャップ",
        "吊るす",
        "ハングマン",
        "ハラス",
        "前触れ",
        "硬化した",
        "硬度",
        "苦難",
        "遊女",
        "害",
        "有害な",
        "悲惨な",
        "ハリー",
        "ハーシュネス",
        "ハッシュ",
        "ハッシュ",
        "急いで",
        "嫌い",
        "憎む",
        "嫌う",
        "憎しみ",
        "傲慢",
        "出没する",
        "幽霊の",
        "大混乱",
        "危険",
        "危険な",
        "ヘイズ",
        "頭痛",
        "頭がおかしい",
        "聴覚",
        "伝聞",
        "霊柩車",
        "心痛",
        "胸焼け",
        "無情な",
        "異教徒",
        "重く",
        "ヒール",
        "高まる",
        "凶悪な",
        "地獄",
        "地獄",
        "無力",
        "無力",
        "出血",
        "痔核",
        "異端",
        "異端者",
        "雌雄同体",
        "ヘロイン",
        "ヘルペス",
        "ヘルペスウイルス",
        "躊躇",
        "隠された",
        "恐ろしいです",
        "妨害する",
        "支障",
        "ヒッピー",
        "ヒス",
        "騒がしい",
        "ヒット",
        "これまで",
        "ハイブ",
        "ひどい",
        "老人",
        "でっち上げ",
        "ホーボー",
        "豚",
        "中空",
        "ホロコースト",
        "ホームレス",
        "ホームシック",
        "殺人的な",
        "殺人",
        "同性愛",
        "フード",
        "フック",
        "くそ",
        "絶望的な",
        "絶望",
        "大群",
        "恐ろしい",
        "恐ろしく",
        "恐ろしい",
        "恐ろしい",
        "恐るべき",
        "恐ろしい",
        "ホラー",
        "恐怖",
        "人質",
        "敵対的な",
        "戦闘",
        "敵意",
        "うぬぼれ",
        "かわいそう",
        "ハムブグ",
        "屈辱的な",
        "屈辱的な",
        "屈辱",
        "穿刺",
        "空腹",
        "ハンター",
        "狩猟",
        "ハリケーン",
        "急いで",
        "傷つける",
        "傷つける",
        "傷つける",
        "ハスラー",
        "ヒドラ",
        "水頭症",
        "誇大宣伝",
        "誇張",
        "偽善",
        "偽善者",
        "偽善的な",
        "ヒステリー",
        "ヒステリックな",
        "白痴",
        "馬鹿",
        "馬鹿馬鹿しい",
        "アイドラー",
        "偶像崇拝",
        "無知",
        "無知な",
        "無視する",
        "病気",
        "違法",
        "違法",
        "判読不能な",
        "違法",
        "不法",
        "文盲",
        "病気",
        "不合理な",
        "錯覚",
        "模倣した",
        "模倣",
        "未熟",
        "未熟",
        "不道徳な",
        "不道徳",
        "害を与える",
        "減損",
        "難しい",
        "焦り",
        "せっかち",
        "弾劾する",
        "弾劾",
        "妨げる",
        "不完全",
        "不完全",
        "偽装する",
        "偽装",
        "無敵な",
        "関係する",
        "無礼な",
        "面付け",
        "不可能",
        "インポテンス",
        "無力",
        "呼ぶ",
        "実行不可能な",
        "投獄",
        "投獄された",
        "投獄",
        "不正",
        "慎重な",
        "不純な",
        "不純物",
        "帰属",
        "無能",
        "アクセスできない",
        "不正確",
        "無反応",
        "不活動",
        "NO TRANSLATION",
        "不十分な",
        "容認できない",
        "イン・イン",
        "適用外",
        "不適切",
        "不注意",
        "聞き取れない",
        "計り知れない",
        "無能",
        "投獄",
        "万一に備えて",
        "焼夷弾",
        "香",
        "絶え間ない",
        "近親相姦",
        "近親相姦",
        "焼却",
        "扇動する",
        "厄介な",
        "インコヒーレントな",
        "互換性のない",
        "無能",
        "無能な",
        "不完全さ",
        "理解不能な",
        "不自然な",
        "重要ではない",
        "不注意",
        "不一致",
        "不便",
        "間違った",
        "信じられない",
        "批判",
        "インキュカス",
        "発生する",
        "不治の",
        "侵略",
        "卑劣な",
        "絶望",
        "決定的ではない",
        "無責任な",
        "補償する",
        "契約",
        "不確定",
        "起訴",
        "起訴",
        "無関心",
        "貧しい",
        "憤慨する",
        "憤慨",
        "不明瞭",
        "教え",
        "怠惰な",
        "効果がない",
        "効果のない",
        "非効率",
        "非効率的な",
        "不適格",
        "不適格",
        "不平等",
        "不公平な",
        "不活性",
        "使えない",
        "NO TRANSLATION",
        "経験の浅い",
        "不可解",
        "悪名高い",
        "汚名",
        "幼児期",
        "幼児",
        "梗塞",
        "感染する",
        "感染",
        "感染性の",
        "下位",
        "劣等",
        "インフェルノ",
        "不妊",
        "侵入",
        "異端者",
        "不倫",
        "虚弱",
        "虚弱",
        "炎症",
        "膨張した",
        "インフレーション",
        "与える",
        "犠牲",
        "インフルエンザ",
        "情報提供者",
        "違反",
        "まれに",
        "侵害",
        "阻害する",
        "不愉快な",
        "非人道的な",
        "非人道的な",
        "不自然な",
        "不法",
        "差止命令",
        "けがをする",
        "負傷した",
        "有害な",
        "損傷",
        "不正",
        "受刑者",
        "動作不能",
        "狂人",
        "狂気",
        "安全でない",
        "不安",
        "陰気な",
        "無意味",
        "些細な",
        "気味の悪い",
        "寛大な",
        "倒産",
        "支払不能",
        "不安定",
        "誘拐する",
        "扇動",
        "不足",
        "不十分",
        "不十分に",
        "侮辱",
        "侮辱",
        "反抗的な",
        "忍耐強い",
        "暴動",
        "インター",
        "阻止",
        "干渉",
        "埋葬",
        "割り込み",
        "中断された",
        "埋葬",
        "威圧する",
        "脅迫",
        "耐え難い",
        "不寛容",
        "寛容な",
        "酔う",
        "扱いにくい",
        "陰謀",
        "侵入者",
        "侵入",
        "介入する",
        "侵入する",
        "インベーダー",
        "無効にする",
        "無効化",
        "無効",
        "侵入",
        "不随意の",
        "退陣",
        "怒る",
        "NO TRANSLATION",
        "アイアン",
        "不合理な",
        "不合理",
        "和解できない",
        "不規則な",
        "不規則",
        "無関係",
        "修復不可能な",
        "無責任な",
        "不平",
        "取消不能",
        "過敏症",
        "過敏な",
        "刺激",
        "刺激",
        "分離された",
        "隔離",
        "ジャバー",
        "刑務所",
        "専門用語",
        "嫌な",
        "黄疸",
        "嫉妬",
        "嫉妬",
        "脅かす",
        "危険",
        "ジョン",
        "冗談で",
        "NO TRANSLATION",
        "混乱",
        "ジャンク",
        "ジュンタ",
        "少年",
        "カーン",
        "キック",
        "誘拐する",
        "殺します",
        "殺す",
        "凧",
        "刻む",
        "結ばれた",
        "労苦",
        "面倒な",
        "ラビリンス",
        "欠如",
        "欠けている",
        "鈍い",
        "ラディン",
        "遅れ",
        "遅れ",
        "恋人",
        "嘆く",
        "地滑り",
        "ぐずぐず",
        "衰弱する",
        "衰弱する",
        "経過",
        "窃盗",
        "ラッシュ",
        "遅く",
        "遅れ",
        "潜在",
        "トイレ",
        "ばかばかしい",
        "溶岩",
        "無法",
        "訴訟",
        "弁護士",
        "怠惰",
        "下剤",
        "怠惰な",
        "リーク",
        "漏れ",
        "漏れた",
        "離れる",
        "リーチ",
        "ヒルズ",
        "NO TRANSLATION",
        "レモン",
        "ハンセン病",
        "レズビアン",
        "軽減する",
        "小さい",
        "致死",
        "無気力",
        "白血病",
        "徴収",
        "うそつき",
        "リエゾン",
        "うそつき",
        "名誉毀損",
        "舐める",
        "嘘つき",
        "生命のない",
        "限られた",
        "麻痺させる",
        "糸くず",
        "酒",
        "無情な",
        "訴訟",
        "訴訟を起こす",
        "訴訟",
        "訴訟の",
        "くず",
        "鮮やかな",
        "塊",
        "ローファー",
        "NO TRANSLATION",
        "嫌う",
        "嫌悪",
        "嫌な",
        "ロビイスト",
        "NO TRANSLATION",
        "イナゴ",
        "高尚な",
        "孤独",
        "寂しい",
        "寂しい",
        "〜する",
        "織機",
        "ローン",
        "恋人",
        "略奪",
        "失う",
        "負け",
        "損失",
        "失われた",
        "ラウドネス",
        "ラウンジ",
        "怠け者",
        "低い",
        "低下",
        "最低",
        "低地",
        "低い",
        "馬鹿な",
        "伐採",
        "塊",
        "塊状",
        "狂信",
        "狂人",
        "不意打ち",
        "ルアー",
        "甘い",
        "潜む",
        "隠れる",
        "豊かな",
        "欲望",
        "淫らな",
        "嘘つき",
        "リンチ",
        "メース",
        "怒っている",
        "狂人",
        "狂人",
        "狂気",
        "マフィア",
        "疥癬",
        "一時的",
        "病気",
        "倦怠感",
        "マラリア",
        "悪質な",
        "不正行為",
        "奇形",
        "悪意",
        "悪意のある",
        "悪魔",
        "悪性腫瘍",
        "悪性",
        "過誤",
        "マンダマス",
        "NO TRANSLATION",
        "マングル",
        "マニア",
        "マニアック",
        "マニアックな",
        "操作する",
        "操作",
        "殺害",
        "肥料",
        "マル",
        "マージン",
        "栗色",
        "マーティンゲール",
        "殉教者",
        "殉教",
        "マゾヒズム",
        "虐殺",
        "物質主義",
        "物質主義者",
        "蛇行",
        "無意味な",
        "麻疹",
        "干渉する",
        "平凡な",
        "平凡な",
        "メランコリック",
        "憂鬱",
        "近接",
        "メロドラマ",
        "崩壊",
        "脅威",
        "脅迫する",
        "卑劣な",
        "傭兵",
        "無慈悲な",
        "混乱",
        "厄介な",
        "転移",
        "メタノール",
        "うどんこ病",
        "民兵",
        "模倣",
        "最小化する",
        "最小",
        "少数",
        "NO TRANSLATION",
        "誤動作",
        "流産",
        "いたずら",
        "いたずらな",
        "誤解",
        "不正行為",
        "悲惨な",
        "惨めな",
        "不幸",
        "不幸",
        "誤った",
        "事故",
        "誤解",
        "誤解を招く",
        "誤解を招く",
        "誤った管理",
        "ミスマッチ",
        "異名",
        "間違った",
        "間違った",
        "偽って表現する",
        "詐称",
        "虚偽の",
        "行方不明",
        "誤解",
        "間違い",
        "間違った",
        "愛人",
        "NO TRANSLATION",
        "誤解",
        "誤解",
        "悪用",
        "ダニ",
        "暴徒",
        "嘲笑",
        "モッキング",
        "虐待",
        "モノクロ",
        "独占者",
        "モンスーン",
        "モンスター",
        "怪物",
        "ムーディー",
        "偽",
        "病的な",
        "罹患率",
        "死体安置所",
        "瀕死の",
        "ばか",
        "乱暴",
        "小便",
        "死ぬ",
        "死亡",
        "苦行",
        "葬儀屋",
        "蚊",
        "嘆く",
        "悲しみの",
        "嘆く",
        "ムック",
        "泥",
        "混乱する",
        "混乱した",
        "泥だ",
        "マフ",
        "ミュール",
        "ママ",
        "混じる",
        "かゆみ",
        "殺人",
        "殺人犯",
        "殺人的な",
        "暗い",
        "NO TRANSLATION",
        "必死の",
        "変異体",
        "切り裂かれた",
        "切除",
        "反乱",
        "NO TRANSLATION",
        "銃口",
        "近視",
        "鍋",
        "天底",
        "NO TRANSLATION",
        "ナイーブ",
        "無名",
        "おむつ",
        "麻薬",
        "不快な",
        "いたずら",
        "吐き気",
        "吐き気",
        "NO TRANSLATION",
        "必要な",
        "貧しい",
        "凶悪",
        "否定",
        "負",
        "無視する",
        "無視された",
        "無視する",
        "過失",
        "過失",
        "NO TRANSLATION",
        "ニグロ",
        "ネポティズム",
        "神経質な",
        "ネットラー",
        "イラクサ",
        "神経痛",
        "神経症",
        "神経症",
        "ニコチン",
        "うんざりする",
        "悪夢",
        "ニヒリズム",
        "ノイズ",
        "うるさい",
        "NO TRANSLATION",
        "ナンセンス",
        "無意味な",
        "うそ",
        "無実",
        "有害な",
        "迷惑",
        "NO TRANSLATION",
        "無効にする",
        "麻痺する",
        "無感覚",
        "NO TRANSLATION",
        "オアフ",
        "肥満",
        "肥満",
        "帯",
        "出る",
        "死亡記事",
        "異議",
        "不快な",
        "占領",
        "債務者",
        "抹消する",
        "抹消された",
        "閉塞",
        "忘却",
        "嫌な",
        "猥褻",
        "猥褻",
        "あいまい",
        "障害",
        "頑固な",
        "妨害する",
        "妨害",
        "閉塞性の",
        "鈍い",
        "オカルト",
        "奇妙",
        "不愉快な",
        "臭い",
        "怒る",
        "怒る",
        "違反者",
        "犯罪",
        "攻撃",
        "手放す",
        "オフ",
        "鬼",
        "嗅覚",
        "寡頭制",
        "前兆",
        "不吉",
        "省略する",
        "不利な",
        "責任",
        "泡立つ",
        "不透明",
        "オペラ",
        "アヘン剤",
        "賛美された",
        "アヘン",
        "相手",
        "反対する",
        "反対",
        "反対",
        "抑圧する",
        "抑圧",
        "抑圧的な",
        "抑圧者",
        "オーク",
        "試練",
        "武器",
        "孤児",
        "表向き",
        "失う",
        "流出した",
        "抗議",
        "アウトハウス",
        "異邦人",
        "無法者",
        "怒り",
        "オベーション",
        "圧倒",
        "過剰な",
        "曇った",
        "過ぎる",
        "過量",
        "延滞",
        "過大評価された",
        "オーバーフロー",
        "成長し過ぎた",
        "過負荷",
        "過払い",
        "過大な力",
        "圧倒",
        "高価",
        "見落とし",
        "打倒",
        "覆す",
        "圧倒する",
        "圧倒される",
        "負担",
        "酸化",
        "痛み",
        "痛い",
        "痛い",
        "痛い",
        "痛み",
        "麻痺",
        "パンデミック",
        "NO TRANSLATION",
        "パニック",
        "麻痺",
        "麻痺した",
        "パラノイア",
        "寄生虫",
        "NO TRANSLATION",
        "オウム",
        "間違った",
        "パルチザン",
        "NO TRANSLATION",
        "受動的",
        "受動性",
        "パッチ",
        "哀れな",
        "懐かしい",
        "NO TRANSLATION",
        "不足",
        "貧しい",
        "ポーン",
        "払い戻し",
        "支払い",
        "特色",
        "歩行者",
        "刑罰",
        "ペナルティ",
        "浸透",
        "刑務所",
        "堕落",
        "危険",
        "危険な",
        "滅びる",
        "腐りやすい",
        "死んだ",
        "滅びる",
        "偽証",
        "悪性",
        "加害者",
        "永続化",
        "困惑",
        "困惑",
        "迫害",
        "迫害",
        "摂動",
        "百日咳",
        "勘違いする",
        "倒錯",
        "変態",
        "堕ちた",
        "悲観主義",
        "悲観主義者",
        "害虫",
        "疫病",
        "ペット",
        "些細な",
        "ファントム",
        "痰",
        "偽物",
        "ピケット",
        "ピケッティング",
        "ピクルス",
        "豚",
        "鳩",
        "杭",
        "略奪",
        "ポン引き",
        "にきび",
        "パイン",
        "ピニオン",
        "ピケ",
        "海賊行為",
        "海賊",
        "ピストル",
        "落とし穴",
        "盗作",
        "ペスト",
        "原告",
        "めっきされた",
        "プレーヤー",
        "嘆願",
        "窮地",
        "プロッディング",
        "激しい",
        "略奪",
        "飛び込む",
        "肺炎",
        "密猟",
        "無意味な",
        "毒",
        "中毒",
        "中毒",
        "有毒",
        "ポーク",
        "論争",
        "ポリオ",
        "汚染する",
        "汚染",
        "一夫多妻",
        "華やかさ",
        "おしゃれな",
        "敬虔な",
        "不完全に",
        "ポップ",
        "ポーキュパイン",
        "ポルノ",
        "ポルノ",
        "ポルノ",
        "ポルノ",
        "ポーズ",
        "所有していた",
        "所持",
        "死後の",
        "延期",
        "ポンド",
        "貧困",
        "力のない",
        "いたずら",
        "不安定な",
        "プレシンクト",
        "略奪的な",
        "苦境",
        "妊娠",
        "偏見",
        "偏見のある",
        "不利益な",
        "計画的な",
        "圧力",
        "予期せぬ",
        "ふりをする",
        "ふりをした",
        "ふりをする",
        "かすかな",
        "屈辱",
        "予防的",
        "獲物",
        "刺します",
        "刺すような",
        "刑務所",
        "囚人",
        "秘密",
        "問題",
        "遅らせる",
        "怠慢",
        "不敬",
        "冒涜",
        "豊か",
        "禁じられた",
        "禁止",
        "延長する",
        "無差別",
        "宣伝",
        "起訴",
        "起訴",
        "売春婦",
        "売春",
        "挑発",
        "誘発する",
        "揚げる",
        "揚げる",
        "精神病",
        "広報者",
        "ふかふか",
        "パンチ",
        "辛味",
        "罰する",
        "処罰された",
        "罰する",
        "罰",
        "懲罰的",
        "煉獄",
        "パージ",
        "膿",
        "突っ込む",
        "泥沼",
        "ウズラ",
        "困惑",
        "喧嘩",
        "粉砕",
        "沈黙",
        "疑わしい",
        "クイックシルヴァー",
        "終了する",
        "震える",
        "震える",
        "クイズ",
        "荒れ狂う",
        "猛烈な",
        "狂犬病",
        "ラック",
        "ラケット",
        "放射線",
        "放射性の",
        "ラドン",
        "怒り",
        "激怒する",
        "ぼろぼろ",
        "襲撃",
        "レール",
        "RAM",
        "放浪",
        "暴走",
        "嫌な",
        "身代金",
        "レイプ",
        "ラプター",
        "野蛮人",
        "発疹",
        "ラット",
        "評価",
        "卑劣な",
        "卑劣な",
        "狂気",
        "反動的",
        "リア",
        "反逆の",
        "叱責",
        "反駁する",
        "反逆者",
        "不況",
        "再犯",
        "無謀",
        "無謀",
        "冗長",
        "還流",
        "耐火物",
        "拒否",
        "ごみ",
        "拒否された",
        "回帰",
        "回帰",
        "後悔",
        "残念な",
        "後悔した",
        "後悔する",
        "規制上の",
        "元気",
        "拒絶する",
        "拒否された",
        "拒絶",
        "拒否",
        "再発",
        "降格",
        "放棄する",
        "嫌な",
        "差し戻し",
        "修復",
        "放棄",
        "後悔する",
        "除去",
        "除去する",
        "NO TRANSLATION",
        "NO TRANSLATION",
        "反逆者",
        "放棄する",
        "放棄",
        "NO TRANSLATION",
        "忌避剤",
        "反発",
        "抑圧する",
        "抑圧",
        "戒告",
        "再版",
        "報復",
        "非難する",
        "共和国",
        "否認",
        "反発",
        "廃止する",
        "取り消し",
        "再送",
        "憤慨する",
        "憤慨",
        "辞任する",
        "辞任",
        "辞任した",
        "レジスト",
        "抵抗",
        "耐性のある",
        "抵抗する",
        "抑える",
        "制限する",
        "制限",
        "制限的",
        "報復する",
        "報復",
        "報復的",
        "リタード",
        "遅延",
        "寡黙",
        "レトルト",
        "収縮する",
        "後退",
        "縮退",
        "報復",
        "逆行性の",
        "復讐",
        "逆転",
        "失効",
        "取り消す",
        "反乱",
        "反乱",
        "リボルバー",
        "嫌悪",
        "リウマチ",
        "ぎこちない",
        "謎の",
        "嘲笑",
        "ばかげた",
        "蔓延",
        "ライフル",
        "リフト",
        "堅い",
        "剛性",
        "厳しい",
        "厳しい",
        "リンガー",
        "暴動",
        "暴動",
        "リスク",
        "リスキーな",
        "競争",
        "奪う",
        "強盗",
        "強盗",
        "不正",
        "ルーク",
        "腐敗",
        "腐っている",
        "粗さ",
        "NO TRANSLATION",
        "行",
        "乱暴な",
        "ごみ",
        "瓦礫",
        "後ろの",
        "フリル",
        "頑丈な",
        "台無し",
        "台無し",
        "破滅的な",
        "噂",
        "逃げる",
        "破裂",
        "NO TRANSLATION",
        "さびた",
        "さびた",
        "無慈悲な",
        "NO TRANSLATION",
        "サボタージュ",
        "犠牲",
        "悲しいことに",
        "悲しみ",
        "たるみ",
        "汁",
        "皮肉",
        "肉腫",
        "霊性",
        "悪魔的な",
        "飽和した",
        "野蛮人",
        "野蛮人",
        "疥癬",
        "足場",
        "メス",
        "鱗片状",
        "スキャンダル",
        "スキャンダル",
        "乏しい",
        "呪われた",
        "傷跡",
        "乏しい",
        "ほとんどない",
        "希少",
        "恐怖",
        "スカベンジャー",
        "スキーム",
        "分裂",
        "統合失調症",
        "坐骨神経痛",
        "嘲笑する",
        "叱る",
        "叱る",
        "焦げる",
        "軽蔑",
        "サソリ",
        "スコッチ",
        "悪党",
        "惨めさ",
        "スクランブリング",
        "スクレイピー",
        "悲鳴",
        "悲鳴を上げる",
        "酔っぱらい",
        "ねじ込まれた",
        "スクリメージ",
        "スクラブ",
        "吟味する",
        "精査",
        "スカム",
        "サーチ",
        "離脱",
        "一人",
        "NO TRANSLATION",
        "分泌",
        "秘密の",
        "宗派",
        "扇動",
        "誘惑する",
        "誘惑",
        "分離する",
        "分離された",
        "押収する",
        "利己的",
        "利己主義",
        "老人",
        "無意味な",
        "文",
        "分離主義者",
        "敗血症",
        "敗血症",
        "隔離",
        "穏やかな",
        "蛇",
        "サーバント",
        "サーブ",
        "卑劣な",
        "勤労",
        "後退",
        "断る",
        "下水",
        "下水",
        "手のひら",
        "小屋",
        "足かせ",
        "日陰",
        "振る",
        "不安定な",
        "偽物",
        "騒ぎ",
        "恥",
        "恥ずべき",
        "恥知らずの",
        "上海",
        "鮫",
        "粉砕する",
        "砕けた",
        "杼口",
        "シェル",
        "棚上げ",
        "難破船",
        "たわごと",
        "震える",
        "ショック",
        "うんざりする",
        "シュート",
        "射撃",
        "万引き",
        "不足",
        "欠点",
        "ショット",
        "突っ込む",
        "派手",
        "悲鳴",
        "甲高い",
        "シュリンク",
        "縮小",
        "シャダー",
        "避ける",
        "病気",
        "嫌な",
        "病気",
        "病気",
        "愚かな",
        "NO TRANSLATION",
        "罪深い",
        "不吉な",
        "罪人",
        "罪を犯す",
        "サイレン",
        "シシー",
        "懐疑的な",
        "スケッチ",
        "歪んだ",
        "スキッド",
        "スキップ",
        "小競り合い",
        "スラック",
        "スラグ",
        "スラム",
        "中傷",
        "中傷的な",
        "平手打ち",
        "虐殺",
        "屠殺場",
        "屠殺",
        "スレーブ",
        "奴隷",
        "殺す",
        "殺人者",
        "ぬいぐるみ",
        "ぬるぬる",
        "失神する",
        "スリップ",
        "NO TRANSLATION",
        "汚い",
        "ナマケモノ",
        "恥ずかしがる",
        "脱落",
        "遅さ",
        "スラッジ",
        "スラグ",
        "鈍い",
        "スラム",
        "スランプ",
        "スラー",
        "スラッシュ",
        "ふしだらな女",
        "狡猾",
        "スマック",
        "小さい",
        "スマッシュ",
        "壊された",
        "まばゆい",
        "臭い",
        "臭い",
        "笑顔",
        "打撃",
        "喫煙者",
        "吸う",
        "汚れ",
        "酔っぱらい",
        "密かに",
        "密輸業者",
        "密輸",
        "スマット",
        "ひどい",
        "スラッグ",
        "ヘビ",
        "スネア",
        "うんざり",
        "うんざり",
        "こっそりした",
        "忍び寄る",
        "卑しい",
        "くしゃみ",
        "殺す",
        "スノッブ",
        "浸す",
        "NO TRANSLATION",
        "社会主義者",
        "土壌",
        "汚れた",
        "体性の",
        "憂鬱な",
        "すす",
        "魔術",
        "ソーダイド",
        "痛み",
        "痛い",
        "痛み",
        "悲しみ",
        "悲しい",
        "NO TRANSLATION",
        "魂のない",
        "ソウルメイト",
        "サワー",
        "つまむ",
        "けいれん",
        "吐き出す",
        "槍",
        "斑点",
        "幽霊",
        "スペクトル",
        "投機",
        "過ごした",
        "スピンスター",
        "邪悪",
        "気まずい",
        "はしご",
        "スプリット",
        "分割",
        "台無しにする",
        "スポイラー",
        "スポーク",
        "スポンジ",
        "話す",
        "捻挫",
        "酒宴",
        "スプライト",
        "擬似",
        "スコール",
        "散布機",
        "嫌な",
        "スケルチ",
        "酔う",
        "刺す",
        "驚異的な",
        "停滞している",
        "染色",
        "失効した",
        "茎",
        "スタンドオフ",
        "停止",
        "凝視する",
        "元気",
        "驚愕",
        "餓死",
        "飢えた",
        "飢えている",
        "定常",
        "溜まる",
        "スチール",
        "窃盗",
        "隠密",
        "ステレオタイプ",
        "ステレオタイプ",
        "無菌",
        "滅菌",
        "船尾",
        "堅い",
        "剛性",
        "窒息する",
        "渋った",
        "汚名",
        "胎児",
        "刺す",
        "刺す",
        "刺青",
        "悪臭",
        "臭い",
        "スティント",
        "株式",
        "盗まれた",
        "石",
        "ストーンズ",
        "便",
        "停止",
        "嵐",
        "嵐",
        "緊張した",
        "海峡",
        "一本鎖",
        "ストレンジャー",
        "絞首刑",
        "迷い",
        "応力",
        "闘争",
        "ストライク",
        "ストリップ",
        "ストライプ",
        "ストリップされた",
        "ストローク",
        "闘争",
        "ストラット",
        "ぬるい",
        "つまずく",
        "唖然",
        "減速した",
        "愚か",
        "愚かな",
        "馬鹿",
        "スティー",
        "征服する",
        "主題",
        "被害者",
        "服従",
        "征服",
        "下位",
        "召喚",
        "沈下",
        "補助金",
        "生存者",
        "減算",
        "転覆",
        "破壊的な",
        "破壊する",
        "負ける",
        "吸う",
        "吸盤",
        "訴える",
        "苦しむ",
        "苦しむ人",
        "苦しみ",
        "窒息する",
        "窒息",
        "自殺",
        "自殺",
        "サレン",
        "召喚",
        "沈んだ",
        "面白い",
        "余分な",
        "迷信の",
        "抑圧する",
        "抑制",
        "追加料金",
        "ひどい",
        "降伏",
        "降伏",
        "影響を受けやすいです",
        "容疑者",
        "サスペンション",
        "疑い",
        "疑わしい",
        "スワブ",
        "沼地",
        "沼地",
        "卍",
        "腫れ",
        "泳ぐ",
        "豚",
        "腫れた",
        "症状",
        "失神",
        "タブー",
        "汚れ",
        "NO TRANSLATION",
        "もつれた",
        "遅刻",
        "遅刻",
        "関税",
        "変色する",
        "タリー",
        "味のない",
        "挑発する",
        "税金",
        "からかう",
        "からかい",
        "退屈な",
        "NO TRANSLATION",
        "嵐",
        "誘惑",
        "共同住宅",
        "ターミナル",
        "終了",
        "シロアリ",
        "ひどい",
        "テロ",
        "テロ",
        "テロリスト",
        "恐れる",
        "破傷風",
        "テザー",
        "盗難",
        "有神論",
        "神聖な",
        "泥棒",
        "渇いた",
        "棘",
        "先天性",
        "思慮のない",
        "スラッシュ",
        "脅威",
        "脅かす",
        "脅かす",
        "スレッシュ",
        "鼓動する",
        "スロットル",
        "刺客",
        "勝つ",
        "雷鳴",
        "邪魔する",
        "ティファ",
        "臆病な",
        "臆病",
        "ちょっとした",
        "猛烈な",
        "疲れた",
        "疲れ",
        "面倒な",
        "タイト",
        "ヒキガエル",
        "タバコ",
        "トイレ",
        "トイズ",
        "許容",
        "歯痛",
        "苦しめる",
        "引き裂かれた",
        "魚雷",
        "熱い",
        "不法行為",
        "不愉快な",
        "拷問",
        "触れた",
        "おしゃれな",
        "タフ",
        "毒性",
        "毒素",
        "悲劇",
        "悲劇的な",
        "裏切り者",
        "不運",
        "トランス",
        "犯罪",
        "飾り付け",
        "トラップ",
        "ごみ",
        "くだらない",
        "外傷性の",
        "NO TRANSLATION",
        "駄作",
        "信じられない",
        "裏切り",
        "反逆",
        "震え",
        "振戦",
        "恐怖",
        "侵入",
        "試練",
        "裁判所",
        "トリック",
        "トリッキー",
        "些細な",
        "トリッピング",
        "トロール",
        "面倒な",
        "トランペット",
        "転落",
        "腫瘍",
        "腫瘍",
        "騒乱",
        "騒々しい",
        "乱気流",
        "乱れる",
        "混乱",
        "つまらない",
        "台風",
        "専制政治",
        "専制",
        "暴君",
        "醜さ",
        "醜い",
        "潰瘍",
        "前側",
        "最終的な",
        "できない",
        "容認できない",
        "説明できない",
        "未承認",
        "添付されていない",
        "達成不可能な",
        "魅力的ではない",
        "無許可",
        "避けられない",
        "認識しない",
        "耐え難い",
        "不信仰",
        "信じられない",
        "生まれていない",
        "凄い",
        "無関心",
        "不確実な",
        "変更不可能な",
        "汚れた",
        "不快な",
        "不経済な",
        "無意識",
        "違憲",
        "コントロールできない",
        "制御されていない",
        "未定",
        "損なわれた",
        "未払い",
        "小さい",
        "望ましくない",
        "望ましくない",
        "元に戻す",
        "不安",
        "不安",
        "未教育",
        "失業者",
        "不等",
        "不均一",
        "説明できない",
        "不公正",
        "不公平",
        "不誠実な",
        "不利な",
        "未完成の",
        "容赦のない",
        "残念な",
        "不親切",
        "満たされていない",
        "未完成",
        "不敬な",
        "恩知らず",
        "不幸",
        "不幸",
        "不健康",
        "神聖な",
        "重要でない",
        "感動しなかった",
        "改善されていない",
        "知らない",
        "初心者",
        "賞賛されない",
        "理解不能な",
        "無意識のうちに",
        "無関心",
        "興味深い",
        "不当",
        "不当な",
        "不当な",
        "不親切",
        "未知の",
        "違法",
        "無免許",
        "不運",
        "管理不能",
        "不自然な",
        "非公式",
        "未払い",
        "不快",
        "人気がない",
        "予測不可能な",
        "準備ができていない",
        "非生産的",
        "不採算",
        "保護されていない",
        "未発表",
        "信頼できない",
        "頼りない",
        "手が出ない",
        "安全でない",
        "不満足な",
        "満足していない",
        "不愉快な",
        "悪意のある",
        "不安定",
        "見苦しい",
        "純粋ではない",
        "言い切れない",
        "不安定な",
        "失敗した",
        "不適切",
        "分からない",
        "サポートされていない",
        "持続不可能な",
        "異教徒",
        "つかまえられない",
        "断ることができない",
        "考えられない",
        "控えめな",
        "時折",
        "無題",
        "言いたくない",
        "不都合な",
        "訓練されていない",
        "真実ではない",
        "信頼できない",
        "不当な",
        "洗われていない",
        "歓迎しない",
        "不気味な",
        "不本意",
        "賢くない",
        "無意味な",
        "価値のない",
        "不屈の",
        "激動",
        "蜂起",
        "騒がしい",
        "動揺",
        "ウニ",
        "緊急",
        "役に立たない",
        "奪う",
        "奪われた",
        "お金",
        "欠員",
        "空いている",
        "曖昧",
        "曖昧さ",
        "駄目に",
        "吸血鬼",
        "消えた",
        "虚栄心",
        "水痘",
        "静脈瘤",
        "植物性",
        "激しい",
        "復讐",
        "復讐",
        "忌むるしい",
        "毒",
        "有毒な",
        "冗長",
        "直前",
        "害虫",
        "対",
        "めまい",
        "拒否",
        "副",
        "悪質な",
        "犠牲者",
        "被害者",
        "悪役",
        "悪質な",
        "悪意のある",
        "違反",
        "暴力",
        "暴力的な",
        "激しく",
        "バイパー",
        "毒性",
        "ウイルス",
        "訪問",
        "ヴィクセン",
        "ボラティリティ",
        "火山",
        "嘔吐",
        "ブードー",
        "下品",
        "下品",
        "脆弱性",
        "コンドル",
        "ワッフル",
        "うめき声",
        "待つ",
        "落ちる",
        "NO TRANSLATION",
        "衰える",
        "欲しい",
        "戦争",
        "監督",
        "ウェア",
        "戦争",
        "好戦的",
        "警告する",
        "ワープ",
        "反り",
        "いぼ",
        "廃棄物",
        "無駄な",
        "無駄な",
        "無駄にする",
        "水っぽい",
        "揺るがす",
        "弱まった",
        "弱く",
        "弱点",
        "着る",
        "疲れた",
        "疲労",
        "疲れた",
        "雑草",
        "泣く",
        "奇妙な",
        "奇妙な",
        "NO TRANSLATION",
        "ウィンチェン",
        "打撃",
        "気まずい",
        "泣き叫ぶ",
        "ホイップ",
        "旋風",
        "ウィスキー",
        "売春婦",
        "邪悪な",
        "邪悪",
        "野生",
        "ワイルドキャット",
        "野火",
        "故意の",
        "ウィン",
        "wimpy",
        "元気づける",
        "魔女",
        "魔術",
        "撤退する",
        "枯れている",
        "枯れた",
        "悲惨",
        "悲惨な",
        "悲惨に",
        "言葉",
        "ワーム",
        "着用した",
        "心配している",
        "心配",
        "心配する",
        "悪化する",
        "悪化する",
        "役に立たない",
        "創傷",
        "論争",
        "怒り",
        "傷つける",
        "難破",
        "壊れた",
        "レンチ",
        "レスリング",
        "惨めな",
        "悲惨な",
        "違う",
        "不正行為",
        "不当",
        "間違って",
        "鍛えた",
        "泣く",
        "異端恐怖症",
        "ハワイ",
        "あくび",
        "エール",
        "黄色",
        "y",
        "ジップ",
    ]
)

_ambivalent = set(
    [
        "豊富",
        "武装した",
        "香ばしい",
        "自慢",
        "騒々しい",
        "ブックワーム",
        "バック",
        "有名人",
        "チャームド〜魔女3姉妹",
        "迂回",
        "共謀",
        "告白する",
        "狡猾な",
        "依存",
        "多様",
        "支配的",
        "無限",
        "強制する",
        "エロティックな",
        "エスケープ",
        "感じ",
        "フライ",
        "雹",
        "快楽主義",
        "最高",
        "謙虚な",
        "すぐに",
        "不動産",
        "所得",
        "浸潤",
        "影響",
        "激しい",
        "断続的な",
        "介入",
        "レース",
        "リベラル",
        "主",
        "母性",
        "助産婦",
        "母",
        "マグ",
        "悪評",
        "全能性",
        "爆発",
        "傑出した",
        "パレード",
        "言い換え",
        "石油",
        "プレゼンテーション",
        "放蕩",
        "見積もり",
        "レイブ",
        "退行性の",
        "やり直す",
        "残っている",
        "退職",
        "復活する",
        "革命",
        "かかし",
        "孤独",
        "官能的な",
        "光景",
        "脊椎",
        "スターリング",
        "多肉植物",
        "迷信",
        "覇権",
        "囲む",
        "同義語",
        "魅力的な",
        "十代の若者たち",
        "治療する",
        "無敗",
        "無制限の",
        "予想外の",
        "想像を絶する",
        "アンティ",
        "上り坂",
        "投票",
        "重量",
        "憧れ",
    ]
)



"""
@author: alfonso.semeraro@unito.it

"""

import re
from emoatlas.language_dependencies import _check_language
import itertools
from nltk import word_tokenize
from emoatlas.resources import _load_spacy, _load_emojis, _load_idiomatic_tokens


def multiple_replace(string, rep_dict):
    pattern = re.compile(
        "|".join([re.escape(k) for k in sorted(rep_dict, key=len, reverse=True)]),
        flags=re.DOTALL,
    )
    return pattern.sub(lambda x: rep_dict[x.group(0)], string)


def _clean_text(text):
    """Preliminary text cleaning: removing weird punctuation from words, stripping spaces."""

    text = text.replace("’", "'")
    text = text.replace('"', "")
    text = text.replace("”", "")
    text = text.replace("“", "")
    text = text.replace("«", "")
    text = text.replace("»", "")
    text = re.sub("\t", " ", text)
    text = re.sub("\n", " ", text)
    text = re.sub("[ ]+", " ", text)
    text = text.lower()
    text = re.sub("\<u\+[0-9A-Za-z]+\>", "", text)
    text = text.strip()

    return text


def _load_text(text, language, tagger, idiomatic_tokens):
    """Loads a wordlist from a text."""

    # clean text
    text = _clean_text(text)

    # Check for language
    _check_language(language)

    # replace idiomatic expressions with tokens
    if language != "english" and idiomatic_tokens:
        text = multiple_replace(text, idiomatic_tokens)

    # get tokens
    if "snowballstemmer" in str(tagger).lower():
        tokens = [tagger.stem(token) for token in word_tokenize(text)]
    elif "spacy" in str(tagger).lower():
        tokens = [token.lemma_ for token in tagger(text)]

    return tokens


def _load_object(obj, tagger, language, emojis_dict, convert_emojis, idiomatic_tokens):
    """Checks the format of the input, then loads the wordlist in the right way."""

    # DEALING WITH STRINGS
    if type(obj) == str:
        text = obj

    # DEALING WITH PANDAS
    elif "pandas.core.frame.Series" in str(type(obj)):
        wordlist = list(itertools.chain(*obj.values))
        text = " ".join(wordlist)

    # DEALING WITH FORMAMENTIS
    elif "FormamentisNetwork" in str(obj.__class__):
        wordlist = obj.vertices
        text = " ".join(wordlist)

    else:
        raise ValueError(
            "Only <str>, <pandas.core.frame.Series> and <FormamentisNetwork> objects accepted as inputs."
        )

    if convert_emojis:
        text = _convert_emojis(text, emojis_dict)

    wordlist = _load_text(
        text=text, tagger=tagger, language=language, idiomatic_tokens=idiomatic_tokens
    )

    return wordlist


def _convert_emojis(text, emojis_dict):
    text = [
        (
            " " + emojis_dict[f"U+{ord(s):X}"] + " "
            if f"U+{ord(s):X}" in emojis_dict
            else s
        )
        for s in text
    ]
    text = "".join(text)
    return text


# Used if you are only interested in lemmatizing texts
def lemmatize_text(text, language="english", idiomaticreplacement=False):
    tagger = _load_spacy(language)
    if idiomaticreplacement:
        idiomatictokens = _load_idiomatic_tokens(language)
    else:
        idiomatictokens = {}
    emojis = _load_emojis(language)

    lemmatized = _load_object(
        text,
        language=language,
        tagger=tagger,
        idiomatic_tokens=idiomatictokens,
        convert_emojis=True,
        emojis_dict=emojis,
    )
    print(lemmatized)
